@@ -94,15 +94,15 @@ namespace etl
 
     static ETL_CONSTANT size_t SIZE = SIZE_;
 
-    typedef T                                     value_type;
-    typedef size_t                                size_type;
-    typedef ptrdiff_t                             difference_type;
-    typedef T&                                    reference;
-    typedef const T&                              const_reference;
-    typedef T*                                    pointer;
-    typedef const T*                              const_pointer;
-    typedef T*                                    iterator;
-    typedef const T*                              const_iterator;
+    typedef T         value_type;
+    typedef size_t    size_type;
+    typedef ptrdiff_t difference_type;
+    typedef T&        reference;
+    typedef const T&  const_reference;
+    typedef T*        pointer;
+    typedef const T*  const_pointer;
+    typedef T*        iterator;
+    typedef const T*  const_iterator;
     typedef ETL_OR_STD::reverse_iterator<iterator>       reverse_iterator;
     typedef ETL_OR_STD::reverse_iterator<const_iterator> const_reverse_iterator;
 
@@ -115,6 +115,7 @@ namespace etl
     ///\param i The index of the element to access.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     reference at(size_t i)
     {
       ETL_ASSERT(i < SIZE, ETL_ERROR(array_out_of_range));
@@ -127,11 +128,7 @@ namespace etl
     ///\param i The index of the element to access.
     //*************************************************************************
     ETL_NODISCARD
-#if defined(ETL_THROW_EXCEPTIONS)
     ETL_CONSTEXPR14
-#else
-    ETL_CONSTEXPR
-#endif
     const_reference at(size_t i) const
     {
       ETL_ASSERT(i < SIZE, ETL_ERROR(array_out_of_range));
@@ -145,6 +142,7 @@ namespace etl
     ///\param i The index of the element to access.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     reference operator[](size_t i)
     {
       return _buffer[i];
@@ -165,6 +163,7 @@ namespace etl
     /// Returns a reference to the first element.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     reference front()
     {
       return _buffer[0];
@@ -183,6 +182,7 @@ namespace etl
     /// Returns a reference to the last element.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     reference back()
     {
       return _buffer[SIZE - 1];
@@ -201,6 +201,7 @@ namespace etl
     /// Returns a pointer to the first element of the internal buffer.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     pointer data() ETL_NOEXCEPT
     {
       return &_buffer[0];
@@ -223,6 +224,7 @@ namespace etl
     /// Returns an iterator to the beginning of the array.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     iterator begin() ETL_NOEXCEPT
     {
       return &_buffer[0];
@@ -250,6 +252,7 @@ namespace etl
     /// Returns an iterator to the end of the array.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     iterator end() ETL_NOEXCEPT
     {
       return _buffer + SIZE;
@@ -277,6 +280,7 @@ namespace etl
     // Returns an reverse iterator to the reverse beginning of the array.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     reverse_iterator rbegin() ETL_NOEXCEPT
     {
       return reverse_iterator(end());
@@ -304,6 +308,7 @@ namespace etl
     /// Returns a reverse iterator to the end of the array.
     //*************************************************************************
     ETL_NODISCARD
+    ETL_CONSTEXPR14
     reverse_iterator rend() ETL_NOEXCEPT
     {
       return reverse_iterator(begin());
@@ -390,11 +395,12 @@ namespace etl
     /// If the range is smaller than the array then the unused array elements are left unmodified.
     ///\param first The iterator to the first item in the range.
     ///\param last  The iterator to one past the final item in the range.
+    ///\return An iterator to the first unassigned array element, or end().
     //*************************************************************************
     template <typename TIterator>
-    void assign(TIterator first, const TIterator last)
+    iterator assign(TIterator first, const TIterator last)
     {
-      etl::copy_s(first, last, begin(), end());
+      return etl::copy_s(first, last, begin(), end());
     }
 
     //*************************************************************************
@@ -402,15 +408,18 @@ namespace etl
     /// If the range is smaller than the array then the unused array elements are initialised with the supplied value.
     ///\param first The iterator to the first item in the range.
     ///\param last  The iterator to one past the final item in the range.
+    ///\return An iterator to the first array element set to 'value', or end().
     //*************************************************************************
     template <typename TIterator>
-    void assign(TIterator first, const TIterator last, parameter_t value)
+    iterator assign(TIterator first, const TIterator last, parameter_t value)
     {
       // Copy from the range.
-      iterator p = etl::copy(first, last, begin());
+      iterator p = etl::copy_s(first, last, begin(), end());
 
       // Initialise any that are left.
       etl::fill(p, end(), value);
+
+      return p;
     }
 
     //*************************************************************************
@@ -608,7 +617,7 @@ namespace etl
   template <typename T, typename... TValues>
   constexpr auto make_array(TValues&&... values) -> etl::array<T, sizeof...(TValues)>
   {
-    return { { etl::forward<T>(values)... } };
+    return { etl::forward<T>(values)... };
   }
 #endif
 
