@@ -502,6 +502,16 @@ namespace etl
       p_buffer[new_size] = 0;
     }
 
+    //*********************************************************************
+    /// Fills the string with the specified character.
+    /// Does not change the string length.
+    ///\param value The character used to fill the string.
+    //*********************************************************************
+    void fill(T value)
+    {
+      etl::fill(begin(), end(), value);
+    }
+
     //*********************************************************************
     /// Returns a reference to the value at index 'i'
     ///\param i The index.
@@ -595,7 +605,7 @@ namespace etl
     /// Returns a const pointer to the beginning of the string data.
     ///\return A const pointer to the beginning of the string data.
     //*********************************************************************
-    const_pointer data() const
+    ETL_CONSTEXPR const_pointer data() const
     {
       return p_buffer;
     }
@@ -703,7 +713,7 @@ namespace etl
       set_truncated(*other != 0);
 
 #if ETL_HAS_ERROR_ON_STRING_TRUNCATION
-      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation))
+      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation));
 #endif
 #endif
 
@@ -724,7 +734,7 @@ namespace etl
       set_truncated(length_ > CAPACITY);
 
 #if ETL_HAS_ERROR_ON_STRING_TRUNCATION
-      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation))
+      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation));
 #endif
 #endif
 
@@ -764,7 +774,7 @@ namespace etl
       set_truncated(first != last);
 
 #if ETL_HAS_ERROR_ON_STRING_TRUNCATION
-      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation))
+      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation));
 #endif
 #endif
     }
@@ -783,7 +793,7 @@ namespace etl
       set_truncated(n > CAPACITY);
 
 #if ETL_HAS_ERROR_ON_STRING_TRUNCATION
-      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation))
+      ETL_ASSERT(flags.test<IS_TRUNCATED>() == false, ETL_ERROR(string_truncation));
 #endif
 #endif
 
@@ -1252,7 +1262,7 @@ namespace etl
     /// Erases a sequence.
     ///\param position Position to start from.
     ///\param length   Number of characters.
-    ///\return A refernce to this string.
+    ///\return A reference to this string.
     //*********************************************************************
     etl::ibasic_string<T>& erase(size_type position, size_type length_ = npos)
     {
@@ -2087,7 +2097,7 @@ namespace etl
       {
         for (size_type i = position; i < size(); ++i)
         {
-          if (p_buffer[i] != c)
+          if (*(p_buffer + i) != c)
           {
             return i;
           }
