@@ -350,7 +350,8 @@ namespace etl
           {
             unsigned char mask_width = static_cast<unsigned char>(etl::min(nbits, bits_available_in_char));
             nbits -= mask_width;
-            uint32_t mask = ((uint32_t(1U) << mask_width) - 1U) << nbits;
+            uint32_t mask = ((1U << mask_width) - 1U) << nbits;
+            //uint32_t mask = ((uint32_t(1U) << mask_width) - 1U) << nbits;
 
             // Move chunk to lowest char bits.
             // Chunks are never larger than one char.
@@ -535,7 +536,8 @@ namespace etl
     //***************************************************************************
     /// Construct from span.
     //***************************************************************************
-    bit_stream_writer(etl::span<char> span_, etl::endian stream_endianness_, callback_type callback_ = callback_type())
+    template <size_t Length>
+    bit_stream_writer(const etl::span<char, Length>& span_, etl::endian stream_endianness_, callback_type callback_ = callback_type())
       : pdata(span_.begin())
       , length_chars(span_.size_bytes())
       , stream_endianness(stream_endianness_)
@@ -547,7 +549,8 @@ namespace etl
     //***************************************************************************
     /// Construct from span.
     //***************************************************************************
-    bit_stream_writer(etl::span<unsigned char> span_, etl::endian stream_endianness_, callback_type callback_ = callback_type())
+    template <size_t Length>
+    bit_stream_writer(const etl::span<unsigned char, Length>& span_, etl::endian stream_endianness_, callback_type callback_ = callback_type())
       : pdata(reinterpret_cast<char*>(span_.begin()))
       , length_chars(span_.size_bytes())
       , stream_endianness(stream_endianness_)
@@ -626,7 +629,7 @@ namespace etl
     void write_unchecked(bool value)
     {
       unsigned char chunk = value ? 1 : 0;
-      write_data<unsigned char>(static_cast<unsigned char>(chunk), 1);
+      write_data<unsigned char>(chunk, 1);
     }
 
     //***************************************************************************
@@ -858,7 +861,7 @@ namespace etl
     }
 
     //***************************************************************************
-    /// Sets the function to call afer every write.
+    /// Sets the function to call after every write.
     //***************************************************************************
     void set_callback(callback_type callback_)
     {
@@ -866,7 +869,7 @@ namespace etl
     }
 
     //***************************************************************************
-    /// Gets the function to call afer every write.
+    /// Gets the function to call after every write.
     //***************************************************************************
     callback_type get_callback() const
     {
@@ -1031,7 +1034,8 @@ namespace etl
     //***************************************************************************
     /// Construct from span.
     //***************************************************************************
-    bit_stream_reader(etl::span<char> span_, etl::endian stream_endianness_)
+    template <size_t Length>
+    bit_stream_reader(const etl::span<char, Length>& span_, etl::endian stream_endianness_)
       : pdata(span_.begin())
       , length_chars(span_.size_bytes())
       , stream_endianness(stream_endianness_)
@@ -1042,8 +1046,33 @@ namespace etl
     //***************************************************************************
     /// Construct from span.
     //***************************************************************************
-    bit_stream_reader(etl::span<unsigned char> span_, etl::endian stream_endianness_)
-      : pdata(reinterpret_cast<char*>(span_.begin()))
+    template <size_t Length>
+    bit_stream_reader(const etl::span<unsigned char, Length>& span_, etl::endian stream_endianness_)
+      : pdata(reinterpret_cast<const char*>(span_.begin()))
+      , length_chars(span_.size_bytes())
+      , stream_endianness(stream_endianness_)
+    {
+      restart();
+    }
+
+    //***************************************************************************
+    /// Construct from span.
+    //***************************************************************************
+    template <size_t Length>
+    bit_stream_reader(const etl::span<const char, Length>& span_, etl::endian stream_endianness_)
+      : pdata(span_.begin())
+      , length_chars(span_.size_bytes())
+      , stream_endianness(stream_endianness_)
+    {
+      restart();
+    }
+
+    //***************************************************************************
+    /// Construct from span.
+    //***************************************************************************
+    template <size_t Length>
+    bit_stream_reader(const etl::span<const unsigned char, Length>& span_, etl::endian stream_endianness_)
+      : pdata(reinterpret_cast<const char*>(span_.begin()))
       , length_chars(span_.size_bytes())
       , stream_endianness(stream_endianness_)
     {
@@ -1054,8 +1083,8 @@ namespace etl
     /// Construct from range.
     //***************************************************************************
     bit_stream_reader(void* begin_, void* end_, etl::endian stream_endianness_)
-      : pdata(reinterpret_cast<char*>(begin_))
-      , length_chars(etl::distance(reinterpret_cast<char*>(begin_), reinterpret_cast<char*>(end_)))
+      : pdata(reinterpret_cast<const char*>(begin_))
+      , length_chars(etl::distance(reinterpret_cast<const char*>(begin_), reinterpret_cast<const char*>(end_)))
       , stream_endianness(stream_endianness_)
     {
       restart();
@@ -1065,7 +1094,7 @@ namespace etl
     /// Construct from begin and length.
     //***************************************************************************
     bit_stream_reader(void* begin_, size_t length_, etl::endian stream_endianness_)
-      : pdata(reinterpret_cast<char*>(begin_))
+      : pdata(reinterpret_cast<const char*>(begin_))
       , length_chars(length_)
       , stream_endianness(stream_endianness_)
     {
@@ -1318,7 +1347,7 @@ namespace etl
       bits_available -= nbits;
     }
 
-    char*             pdata;                  ///< The start of the bitstream buffer.
+    const char*       pdata;                  ///< The start of the bitstream buffer.
     size_t            length_chars;           ///< The length, in char, of the bitstream buffer.
     const etl::endian stream_endianness;      ///< The endianness of the stream data.
     unsigned char     bits_available_in_char; ///< The number of available bits in the current char.
