@@ -94,7 +94,7 @@ namespace etl
     callback_timer_data()
       : p_callback(ETL_NULLPTR),
         period(0),
-        delta(etl::timer::state::INACTIVE),
+        delta(etl::timer::state::Inactive),
         id(etl::timer::id::NO_TIMER),
         previous(etl::timer::id::NO_TIMER),
         next(etl::timer::id::NO_TIMER),
@@ -112,7 +112,7 @@ namespace etl
                         bool                 repeating_)
       : p_callback(reinterpret_cast<void*>(p_callback_)),
         period(period_),
-        delta(etl::timer::state::INACTIVE),
+        delta(etl::timer::state::Inactive),
         id(id_),
         previous(etl::timer::id::NO_TIMER),
         next(etl::timer::id::NO_TIMER),
@@ -130,7 +130,7 @@ namespace etl
                         bool                  repeating_)
       : p_callback(reinterpret_cast<void*>(&callback_)),
         period(period_),
-        delta(etl::timer::state::INACTIVE),
+        delta(etl::timer::state::Inactive),
         id(id_),
         previous(etl::timer::id::NO_TIMER),
         next(etl::timer::id::NO_TIMER),
@@ -139,7 +139,6 @@ namespace etl
     {
     }
 
-#if ETL_USING_CPP11
     //*******************************************
     /// ETL delegate callback
     //*******************************************
@@ -149,7 +148,7 @@ namespace etl
                         bool                 repeating_)
             : p_callback(reinterpret_cast<void*>(&callback_)),
               period(period_),
-              delta(etl::timer::state::INACTIVE),
+              delta(etl::timer::state::Inactive),
               id(id_),
               previous(etl::timer::id::NO_TIMER),
               next(etl::timer::id::NO_TIMER),
@@ -157,14 +156,13 @@ namespace etl
               cbk_type(DELEGATE)
     {
     }
-#endif
 
     //*******************************************
     /// Returns true if the timer is active.
     //*******************************************
     bool is_active() const
     {
-      return delta != etl::timer::state::INACTIVE;
+      return delta != etl::timer::state::Inactive;
     }
 
     //*******************************************
@@ -172,7 +170,7 @@ namespace etl
     //*******************************************
     void set_inactive()
     {
-      delta = etl::timer::state::INACTIVE;
+      delta = etl::timer::state::Inactive;
     }
 
     void*                 p_callback;
@@ -315,7 +313,7 @@ namespace etl
 
         timer.previous = etl::timer::id::NO_TIMER;
         timer.next     = etl::timer::id::NO_TIMER;
-        timer.delta    = etl::timer::state::INACTIVE;
+        timer.delta    = etl::timer::state::Inactive;
       }
 
       //*******************************
@@ -324,6 +322,12 @@ namespace etl
         return ptimers[head];
       }
 
+      //*******************************
+      const etl::callback_timer_data& front() const
+      {
+        return ptimers[head];
+      }
+
       //*******************************
       etl::timer::id::type begin()
       {
@@ -587,13 +591,11 @@ namespace etl
                   // Call the function wrapper callback.
                   (*reinterpret_cast<etl::ifunction<void>*>(timer.p_callback))();
                 }
-#if ETL_USING_CPP11
                 else if(timer.cbk_type == callback_timer_data::DELEGATE)
                 {
                     // Call the delegate callback.
                     (*reinterpret_cast<callback_type*>(timer.p_callback))();
                 }
-#endif
               }
 
               has_active = !active_list.empty();
@@ -629,7 +631,7 @@ namespace etl
         if (timer.id != etl::timer::id::NO_TIMER)
         {
           // Has a valid period.
-          if (timer.period != etl::timer::state::INACTIVE)
+          if (timer.period != etl::timer::state::Inactive)
           {
             ETL_DISABLE_TIMER_UPDATES;
             if (timer.is_active())
@@ -706,6 +708,54 @@ namespace etl
       return false;
     }
 
+    //*******************************************
+    /// Check if there is an active timer.
+    //*******************************************
+    bool has_active_timer() const
+    {
+      return !active_list.empty();
+    }
+
+    //*******************************************
+    /// Get the time to the next timer event.
+    /// Returns etl::timer::interval::No_Active_Interval if there is no active timer.
+    //*******************************************
+    uint32_t time_to_next() const
+    {
+      uint32_t delta = static_cast<uint32_t>(etl::timer::interval::No_Active_Interval);
+
+      if (has_active_timer())
+      {
+        delta = active_list.front().delta;
+      }
+
+      return delta;
+    }
+
+    //*******************************************
+    /// Checks if a timer is currently active.
+    /// Returns <b>true</b> if the timer is active, otherwise <b>false</b>.
+    //*******************************************
+    bool is_active(etl::timer::id::type id_) const
+    {
+      // Valid timer id?
+      if (is_valid_timer_id(id_))
+      {
+        if (has_active_timer())
+        {
+          const etl::callback_timer_data& timer = timer_array[id_];
+
+          // Registered timer?
+          if (timer.id != etl::timer::id::NO_TIMER)
+          {
+            return timer.is_active();
+          }
+        }
+      }
+
+      return false;
+    }
+
   protected:
 
     //*******************************************
@@ -725,6 +775,14 @@ namespace etl
 
   private:
 
+    //*******************************************
+    /// Check that the timer id is valid.
+    //*******************************************
+    bool is_valid_timer_id(etl::timer::id::type id_) const
+    {
+      return (id_ < MAX_TIMERS);
+    }
+
     // The array of timer data structures.
     callback_timer_data* const timer_array;
 
@@ -744,7 +802,7 @@ namespace etl
   #endif
 #endif
 
-    etl::timer_semaphore_t process_semaphore;
+    mutable etl::timer_semaphore_t process_semaphore;
 #endif
     uint_least8_t registered_timers;
 
