@@ -38,6 +38,7 @@ SOFTWARE.
 #include "error_handler.h"
 #include "utility.h"
 #include "variant.h"
+#include "initializer_list.h"
 
 namespace etl
 {
@@ -57,12 +58,7 @@ namespace etl
   //***************************************************************************
   /// expected_invalid
   //***************************************************************************
-  template <typename TError>
-  class expected_invalid;
-
-  //*******************************************
-  template<>
-  class expected_invalid<void> : public etl::expected_exception
+  class expected_invalid : public etl::expected_exception
   {
   public:
 
@@ -72,18 +68,6 @@ namespace etl
     }
   };
 
-  //*******************************************
-  template <typename TError>
-  class expected_invalid : etl::expected_invalid<void>
-  {
-  public:
-
-    expected_invalid(string_type file_name_, numeric_type line_number_)
-      : expected_invalid<void>(file_name_, line_number_)
-    {
-    }
-  };
-
   //***************************************************************************
   /// Unexpected type.
   /// etl::unexpected represents an unexpected value stored in etl::expected.
@@ -370,6 +354,7 @@ namespace etl
     {
     }
 
+#if ETL_HAS_INITIALIZER_LIST
     //*******************************************
     /// Construct value type from initializser_list and arguments.
     //*******************************************
@@ -378,6 +363,7 @@ namespace etl
       : storage(il, etl::forward<Args>(args)...)
     {
     }
+#endif
 
     //*******************************************
     /// Construct error type from arguments.
@@ -401,7 +387,7 @@ namespace etl
 #endif
 
     //*******************************************
-    ///
+    /// Copy assign from etl::expected.
     //*******************************************
     this_type& operator =(const this_type& other)
     {
@@ -414,13 +400,14 @@ namespace etl
 
 #if ETL_USING_CPP11
     //*******************************************
-    ///
+    /// Move assign from etl::expected.
     //*******************************************
     this_type& operator =(this_type&& other)
     {
       ETL_STATIC_ASSERT(etl::is_move_constructible<TValue>::value && etl::is_move_constructible<TError>::value, "Not move assignable");
 
       storage = etl::move(other.storage);
+
       return *this;
     }
 #endif
@@ -432,7 +419,8 @@ namespace etl
     {
       ETL_STATIC_ASSERT(etl::is_copy_constructible<TValue>::value, "Value not copy assignable");
 
-      storage = value;
+      storage.template emplace<Value_Type>(value);
+
       return *this;
     }
 
@@ -444,7 +432,8 @@ namespace etl
     {
       ETL_STATIC_ASSERT(etl::is_move_constructible<TValue>::value, "Value not move assignable");
 
-      storage = etl::move(value);
+      storage.template emplace<Value_Type>(etl::move(value));
+
       return *this;
     }
 #endif
@@ -456,7 +445,7 @@ namespace etl
     {
       ETL_STATIC_ASSERT(etl::is_copy_constructible<TError>::value, "Error not copy assignable");
 
-      storage = ue.error();
+      storage.template emplace<Error_Type>(ue.error());
 
       return *this;
     }
@@ -469,7 +458,7 @@ namespace etl
     {
       ETL_STATIC_ASSERT(etl::is_move_constructible<TError>::value, "Error not move assignable");
 
-      storage = etl::move(ue.error());
+      storage.template emplace<Error_Type>(etl::move(ue.error()));
 
       return *this;
     }
@@ -616,23 +605,40 @@ namespace etl
       return etl::move(etl::get<Error_Type>(storage));
     }
 
+
+    //*******************************************
+    /// Swap with another etl::expected.
+    //*******************************************
+    void swap(this_type& other)
+    {
+      using ETL_OR_STD::swap;
+
+      swap(storage, other.storage);
+    }
+
     //*******************************************
     ///
     //*******************************************
     template <typename... Args>
     ETL_CONSTEXPR14 value_type& emplace(Args&&... args) ETL_NOEXCEPT
     {
-      storage.emplace(etl::forward<Args>(args)...);
+      storage.template emplace<value_type>(etl::forward<Args>(args)...);
+
+      return value();
     }
 
     //*******************************************
     ///
     //*******************************************
+#if ETL_HAS_INITIALIZER_LIST
     template <typename U, typename... Args>
-    ETL_CONSTEXPR14 value_type& emplace(std::initializer_list<U>& il, Args&&... args) ETL_NOEXCEPT
+    ETL_CONSTEXPR14 value_type& emplace(std::initializer_list<U> il, Args&&... args) ETL_NOEXCEPT
     {
-      storage.emplace(il, etl::forward<Args>(args)...);
+      storage.template emplace<value_type>(il, etl::forward<Args>(args)...);
+
+      return value();
     }
+#endif
 #else
     //*******************************************
     ///
@@ -665,7 +671,7 @@ namespace etl
     value_type* operator ->()
     {
 #if ETL_IS_DEBUG_BUILD
-      ETL_ASSERT(storage.index() == Value_Type, ETL_ERROR(expected_invalid<TError>));
+      ETL_ASSERT(has_value(), ETL_ERROR(expected_invalid));
 #endif
 
       return etl::addressof(etl::get<value_type>(storage));
@@ -677,7 +683,7 @@ namespace etl
     const value_type* operator ->() const
     {
 #if ETL_IS_DEBUG_BUILD
-      ETL_ASSERT(storage.index() == Value_Type, ETL_ERROR(expected_invalid<TError>));
+      ETL_ASSERT(has_value(), ETL_ERROR(expected_invalid));
 #endif
 
       return etl::addressof(etl::get<value_type>(storage));
@@ -689,7 +695,7 @@ namespace etl
     value_type& operator *() ETL_LVALUE_REF_QUALIFIER
     {
 #if ETL_IS_DEBUG_BUILD
-      ETL_ASSERT(storage.index() == Value_Type, ETL_ERROR(expected_invalid<TError>));
+      ETL_ASSERT(has_value(), ETL_ERROR(expected_invalid));
 #endif
 
       return etl::get<value_type>(storage);
@@ -701,7 +707,7 @@ namespace etl
     const value_type& operator *() const ETL_LVALUE_REF_QUALIFIER
     {
 #if ETL_IS_DEBUG_BUILD
-      ETL_ASSERT(storage.index() == Value_Type, ETL_ERROR(expected_invalid<TError>));
+      ETL_ASSERT(has_value(), ETL_ERROR(expected_invalid));
 #endif
 
       return etl::get<value_type>(storage);
@@ -714,7 +720,7 @@ namespace etl
     value_type&& operator *()&&
     {
 #if ETL_IS_DEBUG_BUILD
-      ETL_ASSERT(storage.index() == Value_Type, ETL_ERROR(expected_invalid<TError>));
+      ETL_ASSERT(has_value(), ETL_ERROR(expected_invalid));
 #endif
 
       return etl::move(etl::get<value_type>(storage));
@@ -726,7 +732,7 @@ namespace etl
     const value_type&& operator *() const&&
     {
 #if ETL_IS_DEBUG_BUILD
-      ETL_ASSERT(storage.index() == Value_Type, ETL_ERROR(expected_invalid<TError>));
+      ETL_ASSERT(has_value(), ETL_ERROR(expected_invalid));
 #endif
 
       return etl::move(etl::get<value_type>(storage));
@@ -930,6 +936,16 @@ namespace etl
     }
 #endif
 
+    //*******************************************
+    /// Swap with another etl::expected.
+    //*******************************************
+    void swap(this_type& other)
+    {
+      using ETL_OR_STD::swap;
+
+      swap(storage, other.storage);
+    }
+
   private:
 
     enum
@@ -943,13 +959,139 @@ namespace etl
 }
 
 //*******************************************
-/// Equivalence operator.
+/// Equivalence operators.
 //*******************************************
-template <typename TError>
+template <typename TValue, typename TError, typename TValue2, typename TError2>
 ETL_CONSTEXPR14
-bool operator ==(const etl::unexpected<TError>& lhs, const etl::unexpected<TError>& rhs)
+bool operator ==(const etl::expected<TValue, TError>& lhs, const etl::expected<TValue2, TError2>& rhs)
 {
-  return lhs.error_value == rhs.error_value;
+  if (lhs.has_value() != rhs.has_value())
+  {
+    return false;
+  }
+  if (lhs.has_value())
+  {
+    return lhs.value() == rhs.value();
+  }
+  return lhs.error() == rhs.error();
+}
+
+//*******************************************
+template <typename TValue, typename TError, typename TValue2>
+ETL_CONSTEXPR14
+bool operator ==(const etl::expected<TValue, TError>& lhs, const TValue2& rhs)
+{
+  if (!lhs.has_value())
+  {
+    return false;
+  }
+  return lhs.value() == rhs;
+}
+
+//*******************************************
+template <typename TValue, typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator ==(const etl::expected<TValue, TError>& lhs, const etl::unexpected<TError2>& rhs)
+{
+  if (lhs.has_value())
+  {
+    return false;
+  }
+  return lhs.error() == rhs.error();
+}
+
+//*******************************************
+template <typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator ==(const etl::expected<void, TError>& lhs, const etl::expected<void, TError2>& rhs)
+{
+  if (lhs.has_value() != rhs.has_value())
+  {
+    return false;
+  }
+  if (lhs.has_value())
+  {
+    return true;
+  }
+  return lhs.error() == rhs.error();
+}
+
+//*******************************************
+template <typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator ==(const etl::expected<void, TError>& lhs, const etl::unexpected<TError2>& rhs)
+{
+  if (lhs.has_value())
+  {
+    return false;
+  }
+  return lhs.error() == rhs.error();
+}
+
+//*******************************************
+template <typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator ==(const etl::unexpected<TError>& lhs, const etl::unexpected<TError2>& rhs)
+{
+  return lhs.error() == rhs.error();
+}
+
+//*******************************************
+template <typename TValue, typename TError, typename TValue2, typename TError2>
+ETL_CONSTEXPR14
+bool operator !=(const etl::expected<TValue, TError>& lhs, const etl::expected<TValue2, TError2>& rhs)
+{
+  return !(lhs == rhs);
+}
+
+//*******************************************
+template <typename TValue, typename TError, typename TValue2>
+ETL_CONSTEXPR14
+bool operator !=(const etl::expected<TValue, TError>& lhs, const TValue2& rhs)
+{
+  return !(lhs == rhs);
+}
+
+//*******************************************
+template <typename TValue, typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator !=(const etl::expected<TValue, TError>& lhs, const etl::unexpected<TError2>& rhs)
+{
+  return !(lhs == rhs);
+}
+
+//*******************************************
+template <typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator !=(const etl::expected<void, TError>& lhs, const etl::expected<void, TError2>& rhs)
+{
+  return !(lhs == rhs);
+}
+
+//*******************************************
+template <typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator !=(const etl::expected<void, TError>& lhs, const etl::unexpected<TError2>& rhs)
+{
+  return !(lhs == rhs);
+}
+
+//*******************************************
+template <typename TError, typename TError2>
+ETL_CONSTEXPR14
+bool operator !=(const etl::unexpected<TError>& lhs, const etl::unexpected<TError2>& rhs)
+{
+  return !(lhs == rhs);
+}
+
+//*******************************************
+/// Swap etl::expected.
+//*******************************************
+template <typename TValue, typename TError>
+ETL_CONSTEXPR14
+void swap(etl::expected<TValue, TError>& lhs, etl::expected<TValue, TError>& rhs)
+{
+  lhs.swap(rhs);
 }
 
 //*******************************************
