@@ -175,7 +175,7 @@ namespace etl
 #if defined(ETL_CHECK_PUSH_POP)
       ETL_ASSERT(!empty(), ETL_ERROR(intrusive_list_empty));
 #endif
-      remove_link(get_head());
+      disconnect_link(get_head());
     }
 
     //*************************************************************************
@@ -196,7 +196,7 @@ namespace etl
 #if defined(ETL_CHECK_PUSH_POP)
       ETL_ASSERT(!empty(), ETL_ERROR(intrusive_list_empty));
 #endif
-      remove_link(get_tail());
+      disconnect_link(get_tail());
     }
 
     //*************************************************************************
@@ -320,7 +320,7 @@ namespace etl
     //*************************************************************************
     /// Remove a link.
     //*************************************************************************
-    void remove_link(link_type& link)
+    void disconnect_link(link_type& link)
     {
       etl::unlink<link_type>(link);
       --current_size;
@@ -329,7 +329,7 @@ namespace etl
     //*************************************************************************
     /// Remove a link.
     //*************************************************************************
-    void remove_link(link_type* link)
+    void disconnect_link(link_type* link)
     {
       etl::unlink<link_type>(*link);
       --current_size;
@@ -375,6 +375,74 @@ namespace etl
       etl::link(terminal_link, terminal_link);
       current_size = 0;
     }
+
+    //*************************************************************************
+    /// Tests if the link is in this list.
+    //*************************************************************************
+    bool is_link_in_list(link_type& search_link) const
+    {
+      link_type* p_link = terminal_link.link_type::etl_next;
+
+      while (p_link != &terminal_link)
+      {
+        if (&search_link == p_link)
+        {
+          return true;
+        }
+
+        p_link = p_link->link_type::etl_next;
+      }
+
+      return false;
+    }
+
+    //*************************************************************************
+    /// Remove the specified node from the list.
+    /// Returns ETL_NULLPTR if the link was not in this list or was the last in the list.
+    //*************************************************************************
+    link_type* remove_link(link_type& link)
+    {
+      link_type* result = ETL_NULLPTR;
+
+      if (is_link_in_list(link))
+      {
+        link_type* p_next = link.etl_next;
+
+        disconnect_link(link);
+
+        if (p_next != &terminal_link)
+        {
+          result = p_next;
+        }
+      }
+
+      return result;
+    }
+
+    //*************************************************************************
+    /// Removes a range of links.
+    //*************************************************************************
+    link_type* remove_link_range(link_type* p_first, link_type* p_last)
+    {
+      // Join the ends.
+      etl::link<link_type>(p_first->etl_previous, p_last);
+
+      while (p_first != p_last)
+      {
+        link_type* p_next = p_first->etl_next;
+        p_first->clear();
+        p_first = p_next;
+      }
+
+      if (p_last == &terminal_link)
+      {
+        return ETL_NULLPTR;
+      }
+      else
+      {
+        return p_last;
+      }
+    }
   };
 
   //***************************************************************************
@@ -392,6 +460,8 @@ namespace etl
 
     typedef intrusive_list<TValue, TLink> list_type;
 
+    typedef TValue node_type;
+
     // STL style typedefs.
     typedef TValue            value_type;
     typedef value_type*       pointer;
@@ -458,7 +528,9 @@ namespace etl
 
       reference operator *() const
       {
+#include "private/diagnostic_null_dereference_push.h"
         return *static_cast<pointer>(p_value);
+#include "private/diagnostic_pop.h"
       }
 
       pointer operator &() const
@@ -724,7 +796,7 @@ namespace etl
       iterator next(position);
       ++next;
 
-      this->remove_link(*position.p_value);
+      this->disconnect_link(*position.p_value);
 
       return next;
     }
@@ -737,7 +809,7 @@ namespace etl
       iterator next(position);
       ++next;
 
-      this->remove_link(*position.p_value);
+      this->disconnect_link(*position.p_value);
 
       return next;
     }
@@ -756,17 +828,9 @@ namespace etl
 
       this->current_size -= etl::distance(first, last);
 
-      // Join the ends.
-      etl::link<link_type>(p_first->etl_previous, p_last);
+      p_last = this->remove_link_range(p_first, p_last);
 
-      while (p_first != p_last)
-      {
-        link_type* p_next = p_first->etl_next;
-        p_first->clear();
-        p_first = p_next;
-      }
-
-      if (p_last == &this->terminal_link)
+      if (p_last == ETL_NULLPTR)
       {
         return end();
       }
@@ -776,6 +840,14 @@ namespace etl
       }
     }
 
+    //*************************************************************************
+    /// Erases the specified node.
+    //*************************************************************************
+    node_type* erase(node_type& node)
+    {
+      return static_cast<node_type*>(this->remove_link(node));
+    }
+
     //*************************************************************************
     /// Removes all but the one element from every consecutive group of equal
     /// elements in the container.
