@@ -1395,11 +1395,16 @@ namespace etl
     //*********************************
     void reset(pointer p_ = pointer()) ETL_NOEXCEPT
     {
-      assert(p_ != p);
+      if (p_ == ETL_NULLPTR || p_ != p)
+      {
+        pointer value = p;
+        p = p_;
 
-      pointer value = p;
-      p = p_;
-      deleter(value);
+        if (value != ETL_NULLPTR)
+        {
+          deleter(value);
+        }
+      }
     }
 
     //*********************************
@@ -1416,23 +1421,16 @@ namespace etl
       return (p != ETL_NULLPTR);
     }
 
-#if ETL_USING_STL && ETL_USING_CPP11
     //*********************************
-    unique_ptr&	operator =(std::nullptr_t) ETL_NOEXCEPT
+    unique_ptr&	operator =(etl::nullptr_t) ETL_NOEXCEPT
     {
-      reset(nullptr);
+      if (p)
+      {
+        reset(ETL_NULLPTR);
+      }
 
       return *this;
     }
-#else
-    //*********************************
-    unique_ptr&	operator =(void*) ETL_NOEXCEPT
-    {
-      reset(NULL);
-
-      return *this;
-    }
-#endif
 
 #if ETL_USING_CPP11
     //*********************************
@@ -1595,17 +1593,27 @@ namespace etl
     {
       pointer value = p;
       p = ETL_NULLPTR;
-      return value;
+      return value; 
     }
 
     //*********************************
     void reset(pointer p_) ETL_NOEXCEPT
     {
-      assert(p_ != p);
+      if (p_ != p)
+      {
+        pointer value = p;
+        p = p_;
 
-      pointer value = p;
-      p = p_;
-      delete[] value;
+        if (value != ETL_NULLPTR)
+        {
+          deleter(value);
+        }
+      }
+    }
+
+    void reset(etl::nullptr_t = ETL_NULLPTR) ETL_NOEXCEPT
+    {
+      reset(pointer());
     }
 
     //*********************************
@@ -1622,23 +1630,13 @@ namespace etl
       return (p != ETL_NULLPTR);
     }
 
-#if ETL_USING_STL && ETL_USING_CPP11
     //*********************************
-    unique_ptr& operator =(std::nullptr_t) ETL_NOEXCEPT
+    unique_ptr& operator =(etl::nullptr_t) ETL_NOEXCEPT
     {
-      reset(nullptr);
+      reset(ETL_NULLPTR);
 
       return *this;
     }
-#else
-    //*********************************
-    unique_ptr& operator =(void*) ETL_NOEXCEPT
-    {
-      reset(NULL);
-
-      return *this;
-    }
-#endif
 
 #if ETL_USING_CPP11
     //*********************************
