@@ -63,6 +63,9 @@ SOFTWARE.
   #include "etl_profile.h"
 #endif
 
+// Null statement
+#define ETL_DO_NOTHING static_cast<void>(0)
+
 // Determine the bit width of the platform.
 #define ETL_PLATFORM_16BIT (UINT16_MAX == UINTPTR_MAX)
 #define ETL_PLATFORM_32BIT (UINT32_MAX == UINTPTR_MAX)
@@ -114,6 +117,17 @@ SOFTWARE.
 
 #define ETL_8BIT_SUPPORT (CHAR_BIT == 8) // Deprecated
 
+//*************************************
+// Some targets support 20bit types.
+#if defined(ETL_USE_20BIT_TYPES)
+  #define ETL_USING_20BIT_TYPES     1
+  #define ETL_NOT_USING_20BIT_TYPES 0
+#else
+  #define ETL_USING_20BIT_TYPES     0
+  #define ETL_NOT_USING_20BIT_TYPES 1
+#endif
+
+
 //*************************************
 // Helper macro for ETL_NO_64BIT_TYPES.
 #if defined(ETL_NO_64BIT_TYPES)
@@ -133,6 +147,16 @@ SOFTWARE.
 // See if we can determine the OS we're compiling on, if haven't already done so in etl_profile.h
 #include "profiles/determine_development_os.h"
 
+//*************************************
+// Helper macro for choosing the variant type.
+#if !ETL_USING_CPP11 || defined(ETL_USE_LEGACY_VARIANT)
+  #define ETL_USING_LEGACY_VARIANT     1
+  #define ETL_NOT_USING_LEGACY_VARIANT 0
+#else
+  #define ETL_USING_LEGACY_VARIANT     0
+  #define ETL_NOT_USING_LEGACY_VARIANT 1
+#endif
+
 //*************************************
 // Check WCHAR_MIN and WCHAR_MAX
 #if !defined(WCHAR_MIN)
@@ -199,6 +223,14 @@ SOFTWARE.
   #define ETL_HAS_IDEQUE_REPAIR 0
 #endif
 
+//*************************************
+// Option to enable repair-after-memcpy for icircular_buffer.
+#if defined(ETL_ICIRCULAR_BUFFER_REPAIR_ENABLE)
+#define ETL_HAS_ICIRCULAR_BUFFER_REPAIR 1
+#else
+#define ETL_HAS_ICIRCULAR_BUFFER_REPAIR 0
+#endif
+
 //*************************************
 // Indicate if C++ exceptions are enabled.
 #if defined(ETL_THROW_EXCEPTIONS)
@@ -231,6 +263,14 @@ SOFTWARE.
   #define ETL_HAS_MUTABLE_ARRAY_VIEW 0
 #endif
 
+//*************************************
+// Indicate if etl::imassage is to be non-virtual.
+#if defined(ETL_MESSAGES_ARE_NOT_VIRTUAL)
+  #define ETL_HAS_VIRTUAL_MESSAGES 0
+#else
+  #define ETL_HAS_VIRTUAL_MESSAGES 1
+#endif
+
 //*************************************
 // The macros below are dependent on the profile.
 // C++11
@@ -238,7 +278,6 @@ SOFTWARE.
   #define ETL_CONSTEXPR                   constexpr
   #define ETL_CONSTEXPR11                 constexpr // Synonym for ETL_CONSTEXPR
   #define ETL_CONSTANT                    constexpr
-  #define ETL_STATIC_CONSTANT             constexpr
   #define ETL_DELETE                      = delete
   #define ETL_EXPLICIT                    explicit
   #define ETL_OVERRIDE                    override
@@ -260,7 +299,6 @@ SOFTWARE.
   #define ETL_CONSTEXPR
   #define ETL_CONSTEXPR11
   #define ETL_CONSTANT                    const
-  #define ETL_STATIC_CONSTANT             static const
   #define ETL_DELETE
   #define ETL_EXPLICIT
   #define ETL_OVERRIDE
@@ -331,26 +369,31 @@ SOFTWARE.
 #endif
 
 //*************************************
-// Determine if the ETL can use char8_t type.
-#if ETL_USING_8BIT_TYPES
-  #if ETL_NO_SMALL_CHAR_SUPPORT
-    typedef int8_t char8_t;
-    #define ETL_HAS_CHAR8_T 1
-    #define ETL_HAS_NATIVE_CHAR8_T 0
-  #else
-    #define ETL_HAS_CHAR8_T 1
-    #define ETL_HAS_NATIVE_CHAR8_T 1
-  #endif
+// C++23
+#if ETL_USING_CPP23 && !defined(ETL_FORCE_NO_ADVANCED_CPP)
+  #define ETL_ASSUME(expression) [[assume(expression)]]
 #else
-  #define ETL_HAS_CHAR8_T 0
+  #define ETL_ASSUME ETL_DO_NOTHING
+#endif
+
+//*************************************
+// Determine if the ETL can use char8_t type.
+#if ETL_NO_SMALL_CHAR_SUPPORT
+#include "private/diagnostic_cxx_20_compat_push.h"
+  typedef uint_least8_t char8_t;
+  #define ETL_HAS_CHAR8_T 1
   #define ETL_HAS_NATIVE_CHAR8_T 0
+#include "private/diagnostic_pop.h"
+#else
+  #define ETL_HAS_CHAR8_T 1
+  #define ETL_HAS_NATIVE_CHAR8_T 1
 #endif
 
 //*************************************
 // Define the large character types if necessary.
 #if ETL_NO_LARGE_CHAR_SUPPORT
-  typedef int16_t char16_t;
-  typedef int32_t char32_t;
+  typedef uint_least16_t char16_t;
+  typedef uint_least32_t char32_t;
   #define ETL_HAS_NATIVE_CHAR16_T 0
   #define ETL_HAS_NATIVE_CHAR32_T 0
 #else
@@ -449,7 +492,7 @@ namespace etl
     static ETL_CONSTANT bool using_generic_compiler           = (ETL_USING_GENERIC_COMPILER == 1);
     static ETL_CONSTANT bool using_legacy_bitset              = (ETL_USING_LEGACY_BITSET == 1);
     static ETL_CONSTANT bool using_exceptions                 = (ETL_USING_EXCEPTIONS == 1);
-
+    
     // Has...
     static ETL_CONSTANT bool has_initializer_list             = (ETL_HAS_INITIALIZER_LIST == 1);
     static ETL_CONSTANT bool has_8bit_types                   = (ETL_USING_8BIT_TYPES == 1);
@@ -465,12 +508,13 @@ namespace etl
     static ETL_CONSTANT bool has_string_clear_after_use       = (ETL_HAS_STRING_CLEAR_AFTER_USE == 1);
     static ETL_CONSTANT bool has_istring_repair               = (ETL_HAS_ISTRING_REPAIR == 1);
     static ETL_CONSTANT bool has_ivector_repair               = (ETL_HAS_IVECTOR_REPAIR == 1);
+    static ETL_CONSTANT bool has_icircular_buffer_repair      = (ETL_HAS_ICIRCULAR_BUFFER_REPAIR == 1);
     static ETL_CONSTANT bool has_mutable_array_view           = (ETL_HAS_MUTABLE_ARRAY_VIEW == 1);
     static ETL_CONSTANT bool has_ideque_repair                = (ETL_HAS_IDEQUE_REPAIR == 1);
+    static ETL_CONSTANT bool has_virtual_messages             = (ETL_HAS_VIRTUAL_MESSAGES == 1);
 
     // Is...
     static ETL_CONSTANT bool is_debug_build                   = (ETL_IS_DEBUG_BUILD == 1);
-
   }
 }
 
