@@ -197,6 +197,22 @@ namespace etl
       etl::push_heap(container.begin(), container.end(), compare);
     }
 #else
+    //*************************************************************************
+    /// Emplaces a value to the queue.
+    /// If asserts or exceptions are enabled, throws an etl::priority_queue_full
+    /// is the priority queue is already full.
+    ///\param value The value to push to the queue.
+    //*************************************************************************
+    void emplace()
+    {
+      ETL_ASSERT(!full(), ETL_ERROR(etl::priority_queue_full));
+
+      // Put element at end
+      container.emplace_back();
+      // Make elements in container into heap
+      etl::push_heap(container.begin(), container.end(), compare);
+    }
+
     //*************************************************************************
     /// Emplaces a value to the queue.
     /// If asserts or exceptions are enabled, throws an etl::priority_queue_full
@@ -383,6 +399,7 @@ namespace etl
     {
       if (&rhs != this)
       {
+        clear();
         move(etl::move(rhs));
       }
 
@@ -519,6 +536,7 @@ namespace etl
     {
       if (&rhs != this)
       {
+        etl::ipriority_queue<T, TContainer, TCompare>::clear();
         etl::ipriority_queue<T, TContainer, TCompare>::move(etl::move(rhs));
       }
 
