@@ -42,11 +42,12 @@ SOFTWARE.
 #include "memory.h"
 #include "array.h"
 #include "byte.h"
+#include "static_assert.h"
 
 #include "private/dynamic_extent.h"
 
-#if ETL_USING_STL && ETL_USING_CPP11
-  #include <array>
+#if ETL_USING_CPP20 && ETL_USING_STL
+  #include <span>
 #endif
 
 ///\defgroup span span
@@ -78,14 +79,6 @@ namespace etl
 
     static ETL_CONSTANT size_t extent = Extent;
 
-    //*************************************************************************
-    /// Default constructor.
-    //*************************************************************************
-    ETL_CONSTEXPR span() ETL_NOEXCEPT
-      : pbegin(ETL_NULLPTR)
-    {
-    }
-
     //*************************************************************************
     /// Construct from iterators + size
     //*************************************************************************
@@ -113,64 +106,6 @@ namespace etl
     {
     }
 
-#if ETL_USING_CPP11
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<(N == Extent) && etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(etl::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-    {
-    }
-
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<(N == Extent) && etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(const etl::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-    {
-    }
-#else
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR span(etl::array<U, N>& a, typename etl::enable_if<(N == Extent) && etl::is_same<typename etl::remove_cv<T>::type, typename etl::remove_cv<U>::type>::value, void>::type* = 0) ETL_NOEXCEPT
-      : pbegin(a.data())
-    {
-    }
-
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR span(const etl::array<U, N>& a, typename etl::enable_if<(N == Extent) && etl::is_same<typename etl::remove_cv<T>::type, typename etl::remove_cv<U>::type>::value, void>::type* = 0) ETL_NOEXCEPT
-      : pbegin(a.data())
-    {
-    }
-#endif
-
-#if ETL_USING_STL && ETL_USING_CPP11
-    //*************************************************************************
-    /// Construct from std::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<(N == Extent) && etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(std::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-    {
-    }
-
-    //*************************************************************************
-    /// Construct from std::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<(N == Extent) && etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(const std::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-    {
-    }
-#endif
-
 #if ETL_USING_CPP11
     //*************************************************************************
     /// Construct from a container or other type that supports
@@ -347,31 +282,15 @@ namespace etl
       return pbegin[i];
     }
 
-    ////*************************************************************************
-    ///// Compare two spans for equality.
-    ////*************************************************************************
-    //template <typename Type2, size_t N2, typename etl::enable_if<etl::is_same<typename etl::remove_cv<Type2>::type, value_type>::value, bool>::type = true>
-    //ETL_NODISCARD ETL_CONSTEXPR bool operator==(const etl::span<Type2, N2>& other) const ETL_NOEXCEPT
-    //{
-    //  return ((begin() == other.begin()) && (Extent == other.size())) ||
-    //         etl::equal(begin(), end(), other.begin(), other.end());
-    //}
-
-    ////*************************************************************************
-    ///// Compare two spans for non-equality.
-    ////*************************************************************************
-    //template <typename Type2, size_t N2, typename etl::enable_if<etl::is_same<typename etl::remove_cv<Type2>::type, value_type>::value, bool>::type = true>
-    //ETL_NODISCARD ETL_CONSTEXPR bool operator!=(const etl::span<Type2, N2>& other) const ETL_NOEXCEPT
-    //{
-    //  return !(*this == other);
-    //}
-
     //*************************************************************************
     /// Obtains a span that is a view over the first COUNT elements of this span.
     //*************************************************************************
     template <size_t COUNT>
     ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> first() const ETL_NOEXCEPT
     {
+      // If Extent is static, check that original span contains at least COUNT elements
+      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? COUNT <= Extent : true, "Original span does not contain COUNT elements");
+
       return etl::span<element_type, COUNT>(pbegin, pbegin + COUNT);
     }
 
@@ -389,6 +308,9 @@ namespace etl
     template <size_t COUNT>
     ETL_NODISCARD ETL_CONSTEXPR etl::span<element_type, COUNT> last() const ETL_NOEXCEPT
     {
+      // If Extent is static, check that original span contains at least COUNT elements
+      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? COUNT <= Extent : true, "Original span does not contain COUNT elements");
+
       return etl::span<element_type, COUNT>(pbegin + Extent - COUNT, (pbegin + Extent));
     }
 
@@ -408,6 +330,12 @@ namespace etl
     ETL_NODISCARD ETL_CONSTEXPR
     etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET> subspan() const ETL_NOEXCEPT
     {
+      // If Extent is static, check that OFFSET is within the original span
+      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? OFFSET <= Extent : true, "OFFSET is not within the original span");
+
+      // If count is also static, check that OFFSET + COUNT is within the original span
+      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) && (COUNT != etl::dynamic_extent) ? COUNT <= (Extent - OFFSET) : true, "OFFSET + COUNT is not within the original span");
+      
       return (COUNT == etl::dynamic_extent) ? etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET>(pbegin + OFFSET, (pbegin + Extent))
                                             : etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET>(pbegin + OFFSET, pbegin + OFFSET + COUNT);
     }
@@ -418,6 +346,12 @@ namespace etl
     template <size_t OFFSET, size_t COUNT>
     etl::span<element_type, COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET> subspan() const
     {
+      // If Extent is static, check that OFFSET is within the original span
+      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) ? OFFSET <= Extent : true, "OFFSET is not within the original span");
+
+      // If count is also static, check that OFFSET + COUNT is within the original span
+      ETL_STATIC_ASSERT((Extent != etl::dynamic_extent) && (COUNT != etl::dynamic_extent) ? COUNT <= (Extent - OFFSET) : true, "OFFSET + COUNT is not within the original span");
+      
       if (COUNT == etl::dynamic_extent)
       {
         return etl::span<element_type, (COUNT != etl::dynamic_extent ? COUNT : Extent - OFFSET)>(pbegin + OFFSET, (pbegin + Extent));
@@ -447,7 +381,7 @@ namespace etl
   /// Span - Dynamic Extent
   //***************************************************************************
   template <typename T>
-  class span<T, etl::dynamic_extent>
+  class  span<T, etl::dynamic_extent>
   {
   public:
 
@@ -506,70 +440,6 @@ namespace etl
     {
     }
 
-#if ETL_USING_CPP11
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(etl::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-      , pend(a.data() + a.size())
-    {
-    }
-
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(const etl::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-      , pend(a.data() + a.size())
-    {
-    }
-#else
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR span(etl::array<U, N>& a, typename etl::enable_if<etl::is_same<typename etl::remove_cv<T>::type, typename etl::remove_cv<U>::type>::value, void>::type* = 0) ETL_NOEXCEPT
-      : pbegin(a.data())
-      , pend(a.data() + a.size())
-    {
-    }
-
-    //*************************************************************************
-    /// Construct from etl::array.
-    //*************************************************************************
-    template <typename U, size_t N>
-    ETL_CONSTEXPR span(const etl::array<U, N>& a, typename etl::enable_if<etl::is_same<typename etl::remove_cv<T>::type, typename etl::remove_cv<U>::type>::value, void>::type* = 0) ETL_NOEXCEPT
-      : pbegin(a.data())
-      , pend(a.data() + a.size())
-    {
-    }
-#endif
-
-#if ETL_USING_STL && ETL_USING_CPP11
-    //*************************************************************************
-    /// Construct from std::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(std::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-      , pend(a.data() + a.size())
-    {
-    }
-
-    //*************************************************************************
-    /// Construct from std::array.
-    //*************************************************************************
-    template <typename U, size_t N, typename = typename etl::enable_if<etl::is_same<etl::remove_cv_t<T>, etl::remove_cv_t<U>>::value, void>::type>
-    ETL_CONSTEXPR span(const std::array<U, N>& a) ETL_NOEXCEPT
-      : pbegin(a.data())
-      , pend(a.data() + a.size())
-    {
-    }
-#endif
-
 #if ETL_USING_CPP11
     //*************************************************************************
     /// Construct from a container or other type that supports
@@ -752,26 +622,6 @@ namespace etl
       return pbegin[i];
     }
 
-    ////*************************************************************************
-    ///// Compare two spans for equality.
-    ////*************************************************************************
-    //template <typename Type2, typename etl::enable_if<etl::is_same<typename etl::remove_cv<Type2>::type, value_type>::value, bool>::type = true>
-    //ETL_NODISCARD ETL_CONSTEXPR bool operator==(const etl::span<Type2>& other) const ETL_NOEXCEPT
-    //{
-    //  return (empty() && other.empty()) ||
-    //         ((begin() == other.begin()) && (end() == other.end())) ||
-    //         etl::equal(begin(), end(), other.begin(), other.end());
-    //}
-
-    ////*************************************************************************
-    ///// Compare two spans for non-equality.
-    ////*************************************************************************
-    //template <typename Type2, typename etl::enable_if<etl::is_same<typename etl::remove_cv<Type2>::type, value_type>::value, bool>::type = true>
-    //ETL_NODISCARD ETL_CONSTEXPR bool operator!=(const etl::span<Type2>& other) const ETL_NOEXCEPT
-    //{
-    //  return !(*this == other);
-    //}
-
     //*************************************************************************
     /// Obtains a span that is a view over the first COUNT elements of this span.
     //*************************************************************************
@@ -881,7 +731,7 @@ namespace etl
 
   //*************************************************************************
   /// Equality function.
-  /// Performs a comparision of the range values.
+  /// Performs a comparison of the range values.
   /// Returns <b>true</b> if one of the following are <b>true</b>
   /// 1. Both spans are empty.
   /// 2. They both point to the same range of data.
