@@ -268,7 +268,7 @@ namespace etl
     //*************************************************************************
     ETL_CONSTEXPR size_t size() const
     {
-      return (mend - mbegin);
+      return static_cast<size_t>(mend - mbegin);
     }
 
     //*************************************************************************
@@ -662,6 +662,7 @@ namespace etl
             if (mbegin[i] == view[j])
             {
               found = true;
+              break;
             }
           }
 
@@ -715,6 +716,7 @@ namespace etl
           if (mbegin[position] == view[j])
           {
             found = true;
+            break;
           }
         }
 
@@ -802,6 +804,7 @@ namespace etl
 
   typedef etl::basic_string_view<char>     string_view;
   typedef etl::basic_string_view<wchar_t>  wstring_view;
+  typedef etl::basic_string_view<char8_t>  u8string_view;
   typedef etl::basic_string_view<char16_t> u16string_view;
   typedef etl::basic_string_view<char32_t> u32string_view;
 
@@ -825,6 +828,15 @@ namespace etl
     return wstring_view(text, length);
   }
 
+  //***********************************
+  template<size_t Array_Size>
+  ETL_CONSTEXPR14 u8string_view make_string_view(const char8_t(&text)[Array_Size])
+  {
+    size_t length = etl::char_traits<char8_t>::length(text, Array_Size - 1U);
+
+    return u8string_view(text, length);
+  }
+
   //***********************************
   template<size_t Array_Size>
   ETL_CONSTEXPR14 u16string_view make_string_view(const char16_t(&text)[Array_Size])
