@@ -652,7 +652,20 @@ namespace etl
     {
       ETL_OR_STD::pair<iterator, bool> result(end(), false);
 
-      ETL_ASSERT(!full(), ETL_ERROR(unordered_set_full));
+      if (full())
+      {
+        iterator iter = find(key);
+        if (iter == end())
+        {
+          ETL_ASSERT_FAIL(ETL_ERROR(unordered_set_full));
+        }
+        else
+        { 
+          result.first = iter;
+          result.second = false;
+          return result;
+        }
+      }
 
       // Get the hash index.
       size_t index = get_bucket_index(key);
@@ -665,13 +678,13 @@ namespace etl
       if (bucket.empty())
       {
         // Get a new node.
-        node_t& node = allocate_data_node();
-        node.clear();
-        ::new (&node.key) value_type(key);
-        ETL_INCREMENT_DEBUG_COUNT
+        node_t* node = allocate_data_node();
+        node->clear();
+        ::new (&node->key) value_type(key);
+        ETL_INCREMENT_DEBUG_COUNT;
 
         // Just add the pointer to the bucket;
-        bucket.insert_after(bucket.before_begin(), node);
+        bucket.insert_after(bucket.before_begin(), *node);
         adjust_first_last_markers_after_insert(&bucket);
 
         result.first = iterator(pbuckets + number_of_buckets, pbucket, pbucket->begin());
@@ -699,13 +712,13 @@ namespace etl
         if (inode == bucket.end())
         {
           // Get a new node.
-          node_t& node = allocate_data_node();
-          node.clear();
-          ::new (&node.key) value_type(key);
-          ETL_INCREMENT_DEBUG_COUNT
+          node_t* node = allocate_data_node();
+          node->clear();
+          ::new (&node->key) value_type(key);
+          ETL_INCREMENT_DEBUG_COUNT;
 
           // Add the node to the end of the bucket;
-          bucket.insert_after(inode_previous, node);
+          bucket.insert_after(inode_previous, *node);
           adjust_first_last_markers_after_insert(&bucket);
           ++inode_previous;
 
@@ -727,7 +740,20 @@ namespace etl
     {
       ETL_OR_STD::pair<iterator, bool> result(end(), false);
 
-      ETL_ASSERT(!full(), ETL_ERROR(unordered_set_full));
+      if (full())
+      {
+        iterator iter = find(key);
+        if (iter == end())
+        {
+          ETL_ASSERT_FAIL(ETL_ERROR(unordered_set_full));
+        }
+        else
+        { 
+          result.first = iter;
+          result.second = false;
+          return result;
+        }
+      }
 
       // Get the hash index.
       size_t index = get_bucket_index(key);
@@ -740,13 +766,13 @@ namespace etl
       if (bucket.empty())
       {
         // Get a new node.
-        node_t& node = allocate_data_node();
-        node.clear();
-        ::new (&node.key) value_type(etl::move(key));
-        ETL_INCREMENT_DEBUG_COUNT
+        node_t* node = allocate_data_node();
+        node->clear();
+        ::new (&node->key) value_type(etl::move(key));
+        ETL_INCREMENT_DEBUG_COUNT;
 
           // Just add the pointer to the bucket;
-          bucket.insert_after(bucket.before_begin(), node);
+          bucket.insert_after(bucket.before_begin(), *node);
         adjust_first_last_markers_after_insert(&bucket);
 
         result.first = iterator(pbuckets + number_of_buckets, pbucket, pbucket->begin());
@@ -774,13 +800,13 @@ namespace etl
         if (inode == bucket.end())
         {
           // Get a new node.
-          node_t& node = allocate_data_node();
-          node.clear();
-          ::new (&node.key) value_type(etl::move(key));
-          ETL_INCREMENT_DEBUG_COUNT
+          node_t* node = allocate_data_node();
+          node->clear();
+          ::new (&node->key) value_type(etl::move(key));
+          ETL_INCREMENT_DEBUG_COUNT;
 
             // Add the node to the end of the bucket;
-            bucket.insert_after(inode_previous, node);
+            bucket.insert_after(inode_previous, *node);
           adjust_first_last_markers_after_insert(&bucket);
           ++inode_previous;
 
@@ -1226,7 +1252,7 @@ namespace etl
               // Destroy the value contents.
               it->key.~value_type();
               ++it;
-              ETL_DECREMENT_DEBUG_COUNT
+              ETL_DECREMENT_DEBUG_COUNT;
             }
 
             // Now it's safe to clear the bucket.
@@ -1246,20 +1272,20 @@ namespace etl
     //*************************************************************************
     /// Move from a range
     //*************************************************************************
-    void move(iterator first, iterator last)
+    void move(iterator b, iterator e)
     {
 #if ETL_IS_DEBUG_BUILD
-      difference_type d = etl::distance(first, last);
+      difference_type d = etl::distance(b, e);
       ETL_ASSERT(d >= 0, ETL_ERROR(unordered_set_iterator));
       ETL_ASSERT(size_t(d) <= max_size(), ETL_ERROR(unordered_set_full));
 #endif
 
-      while (first != last)
+      while (b != e)
       {
-        iterator temp = first;
+        iterator temp = b;
         ++temp;
-        insert(etl::move(*first));
-        first = temp;
+        insert(etl::move(*b));
+        b = temp;
       }
     }
 #endif
@@ -1269,10 +1295,10 @@ namespace etl
     //*************************************************************************
     /// Create a node.
     //*************************************************************************
-    node_t& allocate_data_node()
+    node_t* allocate_data_node()
     {
       node_t* (etl::ipool::*func)() = &etl::ipool::allocate<node_t>;
-      return *(pnodepool->*func)();
+      return (pnodepool->*func)();
     }
 
     //*********************************************************************
@@ -1283,7 +1309,7 @@ namespace etl
       if (size() == 1)
       {
         first = pbucket;
-        last = pbucket;
+        last  = pbucket;
       }
       else
       {
@@ -1301,7 +1327,7 @@ namespace etl
     //*********************************************************************
     /// Adjust the first and last markers according to the erased entry.
     //*********************************************************************
-    void adjust_first_last_markers_after_erase(bucket_t* pcurrent)
+    void adjust_first_last_markers_after_erase(bucket_t* pbucket)
     {
       if (empty())
       {
@@ -1310,7 +1336,7 @@ namespace etl
       }
       else
       {
-        if (pcurrent == first)
+        if (pbucket == first)
         {
           // We erased the first so, we need to search again from where we erased.
           while (first->empty())
@@ -1318,29 +1344,29 @@ namespace etl
             ++first;
           }
         }
-        else if (pcurrent == last)
+        else if (pbucket == last)
         {
           // We erased the last, so we need to search again. Start from the first, go no further than the current last.
-          bucket_t* pcurrent = first;
+          pbucket = first;
           bucket_t* pend = last;
 
           last = first;
 
-          while (pcurrent != pend)
+          while (pbucket != pend)
           {
-            if (!pcurrent->empty())
+            if (!pbucket->empty())
             {
-              last = pcurrent;
+              last = pbucket;
             }
 
-            ++pcurrent;
+            ++pbucket;
           }
         }
       }
     }
 
     //*********************************************************************
-    /// Delete a data noe at the specified location.
+    /// Delete a data node at the specified location.
     //*********************************************************************
     local_iterator delete_data_node(local_iterator iprevious, local_iterator icurrent, bucket_t& bucket)
     {
@@ -1348,7 +1374,7 @@ namespace etl
       icurrent->key.~value_type();                          // Destroy the value.
       pnodepool->release(&*icurrent);                       // Release it back to the pool.
       adjust_first_last_markers_after_erase(&bucket);
-      ETL_DECREMENT_DEBUG_COUNT
+      ETL_DECREMENT_DEBUG_COUNT;
 
       return inext;
     }
@@ -1376,7 +1402,7 @@ namespace etl
     key_equal key_equal_function;
 
     /// For library debugging purposes only.
-    ETL_DECLARE_DEBUG_COUNT
+    ETL_DECLARE_DEBUG_COUNT;
 
       //*************************************************************************
       /// Destructor.
@@ -1401,20 +1427,40 @@ namespace etl
   ///\return <b>true</b> if the sets are equal, otherwise <b>false</b>
   ///\ingroup unordered_set
   //***************************************************************************
-  template <typename TKey, typename TMapped, typename TKeyCompare>
-  bool operator ==(const etl::iunordered_set<TKey, TMapped, TKeyCompare>& lhs, const etl::iunordered_set<TKey, TMapped, TKeyCompare>& rhs)
+  template <typename TKey, typename THash, typename TKeyEqual>
+  bool operator ==(const etl::iunordered_set<TKey, THash, TKeyEqual>& lhs, 
+                   const etl::iunordered_set<TKey, THash, TKeyEqual>& rhs)
   {
     const bool sizes_match = (lhs.size() == rhs.size());
     bool elements_match = true;
 
+    typedef typename etl::iunordered_set<TKey, THash, TKeyEqual>::const_iterator itr_t;
+
     if (sizes_match)
     {
-      for (size_t i = 0; (i < lhs.bucket_count()) && elements_match; ++i)
+      itr_t l_begin = lhs.begin();
+      itr_t l_end   = lhs.end();
+
+      while ((l_begin != l_end) && elements_match)
       {
-        if (!etl::is_permutation(lhs.begin(i), lhs.end(i), rhs.begin(i)))
+        const TKey l_value = *l_begin;
+
+        // See if the lhs key exists in the rhs.
+        ETL_OR_STD::pair<itr_t, itr_t> range = rhs.equal_range(l_value);
+
+        if (range.first != rhs.end())
+        {
+          // See if the values match
+          const TKey r_value = *(range.first);
+
+          elements_match = (r_value == l_value);
+        }
+        else
         {
           elements_match = false;
         }
+
+        ++l_begin;
       }
     }
 
@@ -1428,8 +1474,9 @@ namespace etl
   ///\return <b>true</b> if the sets are not equal, otherwise <b>false</b>
   ///\ingroup unordered_set
   //***************************************************************************
-  template <typename TKey, typename TMapped, typename TKeyCompare>
-  bool operator !=(const etl::iunordered_set<TKey, TMapped, TKeyCompare>& lhs, const etl::iunordered_set<TKey, TMapped, TKeyCompare>& rhs)
+  template <typename TKey, typename THash, typename TKeyEqual>
+  bool operator !=(const etl::iunordered_set<TKey, THash, TKeyEqual>& lhs, 
+                   const etl::iunordered_set<TKey, THash, TKeyEqual>& rhs)
   {
     return !(lhs == rhs);
   }
@@ -1563,7 +1610,7 @@ namespace etl
   template <typename TKey, typename THash = etl::hash<TKey>, typename TKeyEqual = etl::equal_to<TKey>, typename... T>
   constexpr auto make_unordered_set(T&&... keys) -> etl::unordered_set<TKey, sizeof...(T), sizeof...(T), THash, TKeyEqual>
   {
-    return { {etl::forward<T>(keys)...} };
+    return { etl::forward<T>(keys)... };
   }
 #endif
 }
