@@ -229,12 +229,12 @@ namespace etl
       if (current_size < new_size)
       {
         etl::uninitialized_fill_n(p_end, delta, value);
-        ETL_ADD_DEBUG_COUNT(delta)
+        ETL_ADD_DEBUG_COUNT(delta);
       }
       else
       {
         etl::destroy_n(p_end - delta, delta);
-        ETL_SUBTRACT_DEBUG_COUNT(delta)
+        ETL_SUBTRACT_DEBUG_COUNT(delta);
       }
 
       p_end = p_buffer + new_size;
@@ -251,11 +251,11 @@ namespace etl
 #if defined(ETL_DEBUG_COUNT)
       if (size() < new_size)
       {
-        ETL_ADD_DEBUG_COUNT(new_size - size())
+        ETL_ADD_DEBUG_COUNT(new_size - size());
       }
       else
       {
-        ETL_SUBTRACT_DEBUG_COUNT(size() - new_size)
+        ETL_SUBTRACT_DEBUG_COUNT(size() - new_size);
       }
 #endif
 
@@ -263,11 +263,14 @@ namespace etl
     }
 
     //*********************************************************************
-    /// Does nothing.
     /// For compatibility with the STL vector API.
+    /// Does not increase the capacity, as this is fixed.
+    /// Asserts an etl::vector_out_of_bounds error if the request is for more than the capacity.
     //*********************************************************************
-    void reserve(size_t)
+    void reserve(size_t n)
     {
+      (void)n; // Stop 'unused parameter' warning in release mode.
+      ETL_ASSERT(n <= CAPACITY, ETL_ERROR(vector_out_of_bounds));
     }
 
     //*********************************************************************
@@ -363,7 +366,7 @@ namespace etl
     /// Returns a const pointer to the beginning of the vector data.
     ///\return A const pointer to the beginning of the vector data.
     //*********************************************************************
-    const_pointer data() const
+    ETL_CONSTEXPR const_pointer data() const
     {
       return p_buffer;
     }
@@ -389,7 +392,7 @@ namespace etl
       initialise();
 
       p_end = etl::uninitialized_copy(first, last, p_buffer);
-      ETL_ADD_DEBUG_COUNT(uint32_t(etl::distance(first, last)))
+      ETL_ADD_DEBUG_COUNT(uint32_t(etl::distance(first, last)));
     }
 
     //*********************************************************************
@@ -405,7 +408,7 @@ namespace etl
       initialise();
 
       p_end = etl::uninitialized_fill_n(p_buffer, n, value);
-      ETL_ADD_DEBUG_COUNT(uint32_t(n))
+      ETL_ADD_DEBUG_COUNT(uint32_t(n));
     }
 
     //*************************************************************************
@@ -466,10 +469,26 @@ namespace etl
 #endif
       ::new (p_end) T(etl::forward<Args>(args)...);
       ++p_end;
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       return back();
     }
 #else
+    //*********************************************************************
+    /// Constructs a value at the end of the vector.
+    /// If asserts or exceptions are enabled, emits vector_full if the vector is already full.
+    ///\param value The value to add.
+    //*********************************************************************
+    reference emplace_back()
+    {
+#if defined(ETL_CHECK_PUSH_POP)
+      ETL_ASSERT(size() != CAPACITY, ETL_ERROR(vector_full));
+#endif
+      ::new (p_end) T();
+      ++p_end;
+      ETL_INCREMENT_DEBUG_COUNT;
+        return back();
+    }
+
     //*********************************************************************
     /// Constructs a value at the end of the vector.
     /// If asserts or exceptions are enabled, emits vector_full if the vector is already full.
@@ -483,7 +502,7 @@ namespace etl
 #endif
       ::new (p_end) T(value1);
       ++p_end;
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       return back();
     }
 
@@ -500,7 +519,7 @@ namespace etl
 #endif
       ::new (p_end) T(value1, value2);
       ++p_end;
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       return back();
     }
 
@@ -517,7 +536,7 @@ namespace etl
 #endif
       ::new (p_end) T(value1, value2, value3);
       ++p_end;
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       return back();
     }
 
@@ -534,7 +553,7 @@ namespace etl
 #endif
       ::new (p_end) T(value1, value2, value3, value4);
       ++p_end;
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
       return back();
     }
 #endif
@@ -621,7 +640,7 @@ namespace etl
       if (position_ == end())
       {
         p = p_end++;
-        ETL_INCREMENT_DEBUG_COUNT
+        ETL_INCREMENT_DEBUG_COUNT;
       }
       else
       {
@@ -648,7 +667,7 @@ namespace etl
       if (position_ == end())
       {
         p = p_end++;
-        ETL_INCREMENT_DEBUG_COUNT
+        ETL_INCREMENT_DEBUG_COUNT;
       }
       else
       {
@@ -675,7 +694,7 @@ namespace etl
       if (position_ == end())
       {
         p = p_end++;
-        ETL_INCREMENT_DEBUG_COUNT
+        ETL_INCREMENT_DEBUG_COUNT;
       }
       else
       {
@@ -702,7 +721,7 @@ namespace etl
       if (position_ == end())
       {
         p = p_end++;
-        ETL_INCREMENT_DEBUG_COUNT
+        ETL_INCREMENT_DEBUG_COUNT;
       }
       else
       {
@@ -729,7 +748,7 @@ namespace etl
       if (position_ == end())
       {
         p = p_end++;
-        ETL_INCREMENT_DEBUG_COUNT
+        ETL_INCREMENT_DEBUG_COUNT;
       }
       else
       {
@@ -785,14 +804,14 @@ namespace etl
 
       // Construct old.
       etl::uninitialized_move(p_end - construct_old_n, p_end, p_construct_old);
-      ETL_ADD_DEBUG_COUNT(construct_old_n)
+      ETL_ADD_DEBUG_COUNT(construct_old_n);
 
       // Copy old.
       etl::move_backward(p_buffer + insert_begin, p_buffer + insert_begin + copy_old_n, p_buffer + insert_end + copy_old_n);
 
       // Construct new.
       etl::uninitialized_fill_n(p_end, construct_new_n, value);
-      ETL_ADD_DEBUG_COUNT(construct_new_n)
+      ETL_ADD_DEBUG_COUNT(construct_new_n);
 
         // Copy new.
         etl::fill_n(p_buffer + insert_begin, copy_new_n, value);
@@ -842,14 +861,14 @@ namespace etl
 
       // Move construct old.
       etl::uninitialized_move(p_end - construct_old_n, p_end, p_construct_old);
-      ETL_ADD_DEBUG_COUNT(construct_old_n)
+      ETL_ADD_DEBUG_COUNT(construct_old_n);
 
       // Move old.
       etl::move_backward(p_buffer + insert_begin, p_buffer + insert_begin + copy_old_n, p_buffer + insert_end + copy_old_n);
 
       // Copy construct new.
       etl::uninitialized_copy(first + copy_new_n, first + copy_new_n + construct_new_n, p_end);
-      ETL_ADD_DEBUG_COUNT(construct_new_n)
+      ETL_ADD_DEBUG_COUNT(construct_new_n);
 
       // Copy new.
       etl::copy(first, first + copy_new_n, p_buffer + insert_begin);
@@ -909,7 +928,7 @@ namespace etl
 
         // Destroy the elements left over at the end.
         etl::destroy(p_end - n_delete, p_end);
-        ETL_SUBTRACT_DEBUG_COUNT(n_delete)
+        ETL_SUBTRACT_DEBUG_COUNT(n_delete);
         p_end -= n_delete;
       }
 
@@ -1013,7 +1032,7 @@ namespace etl
     void initialise()
     {
       etl::destroy(p_buffer, p_end);
-      ETL_SUBTRACT_DEBUG_COUNT(int32_t(etl::distance(p_buffer, p_end)))
+      ETL_SUBTRACT_DEBUG_COUNT(int32_t(etl::distance(p_buffer, p_end)));
 
       p_end = p_buffer;
     }
@@ -1039,7 +1058,7 @@ namespace etl
     void create_back()
     {
       etl::create_value_at(p_end);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
       ++p_end;
     }
@@ -1050,7 +1069,7 @@ namespace etl
     void create_back(const_reference value)
     {
       etl::create_copy_at(p_end, value);
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
       ++p_end;
     }
@@ -1062,7 +1081,7 @@ namespace etl
     void create_back(rvalue_reference value)
     {
       etl::create_copy_at(p_end, etl::move(value));
-      ETL_INCREMENT_DEBUG_COUNT
+      ETL_INCREMENT_DEBUG_COUNT;
 
       ++p_end;
     }
@@ -1076,7 +1095,7 @@ namespace etl
       --p_end;
 
       etl::destroy_at(p_end);
-      ETL_DECREMENT_DEBUG_COUNT
+      ETL_DECREMENT_DEBUG_COUNT;
     }
 
     // Disable copy construction.
@@ -1328,11 +1347,9 @@ namespace etl
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
 #ifdef ETL_IVECTOR_REPAIR_ENABLE
-    virtual
-#endif
+    virtual void repair() ETL_OVERRIDE
+#else
     void repair()
-#ifdef ETL_IVECTOR_REPAIR_ENABLE
-      ETL_OVERRIDE
 #endif
     {
       ETL_ASSERT_OR_RETURN(etl::is_trivially_copyable<T>::value, ETL_ERROR(etl::vector_incompatible_type));
@@ -1360,7 +1377,7 @@ namespace etl
   template <typename... T>
   constexpr auto make_vector(T&&... t) -> etl::vector<typename etl::common_type_t<T...>, sizeof...(T)>
   {
-    return { { etl::forward<T>(t)... } };
+    return { etl::forward<T>(t)... };
   }
 #endif
 
@@ -1509,9 +1526,10 @@ namespace etl
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
-    void repair()
 #ifdef ETL_IVECTOR_REPAIR_ENABLE
-      ETL_OVERRIDE
+    virtual void repair() ETL_OVERRIDE
+#else
+    void repair()
 #endif
     {
     }
@@ -1631,9 +1649,10 @@ namespace etl
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
-    void repair()
 #ifdef ETL_IVECTOR_REPAIR_ENABLE
-      ETL_OVERRIDE
+    virtual void repair() ETL_OVERRIDE
+#else
+    void repair()
 #endif
     {
       etl::ivector<T*>::repair_buffer(buffer);
@@ -1656,7 +1675,7 @@ namespace etl
   template <typename... T>
   constexpr auto make_vector(T*... t) -> etl::vector<typename etl::common_type_t<T*...>, sizeof...(T)>
   {
-    return { { etl::forward<T*>(t)... } };
+    return { etl::forward<T*>(t)... };
   }
 #endif
 
@@ -1788,9 +1807,10 @@ namespace etl
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
-    void repair()
 #ifdef ETL_IVECTOR_REPAIR_ENABLE
-      ETL_OVERRIDE
+    virtual void repair() ETL_OVERRIDE
+#else
+    void repair()
 #endif
     {
       etl::ivector<T*>::repair_buffer(this->p_buffer);
