@@ -231,9 +231,10 @@ namespace etl
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
 #if ETL_HAS_ISTRING_REPAIR
-    virtual
-#endif
+    virtual void repair() ETL_OVERRIDE
+#else
     void repair()
+#endif
     {
       etl::iwstring::repair_buffer(buffer);
     }
@@ -414,9 +415,10 @@ namespace etl
     //*************************************************************************
     /// Fix the internal pointers after a low level memory copy.
     //*************************************************************************
-    void repair()
 #if ETL_HAS_ISTRING_REPAIR
-      ETL_OVERRIDE
+    virtual void repair() ETL_OVERRIDE
+#else
+    void repair()
 #endif
     {
     }
