@@ -3,29 +3,38 @@ clear
 
 echo -e
 
-testname="Test Name Not Set"
+configuration_name="Configuration Name Not Set"
 
 FailColour='\033[38;2;255;128;128m'
 PassColour='\033[38;2;128;255;128m'
 TitleColour='\033[38;2;107;210;255m'
 NoColour='\033[0m'
 
+ParseGitBranch() 
+{
+    git rev-parse --abbrev-ref HEAD
+}
+
 SetCxxStandard()
 {
 	cxx_standard=$1
 }
 
-SetTestName()
+SetConfigurationName()
 {
-	testname=$1
+	configuration_name=$1
 }
 
 PrintHeader()
 {
 	echo "$TitleColour"
 	echo "============================================================================" | tee -a log.txt
-	echo " $testname                                                                  " | tee -a log.txt
-	echo " Language standard : C++$cxx_standard                                       " | tee -a log.txt
+	echo " Configuration : $configuration_name" | tee -a log.txt
+	echo " Compiler      : $compiler          " | tee -a log.txt
+	echo " Language      : C++$cxx_standard   " | tee -a log.txt
+	echo " ETL version   : $etl_version       " | tee -a log.txt
+	echo " Git branch    : $(ParseGitBranch)  " | tee -a log.txt
+	echo " Processes     : ${CMAKE_BUILD_PARALLEL_LEVEL}" | tee -a log.txt
 	echo "============================================================================" | tee -a log.txt
 	echo "$NoColour"
 }
@@ -34,7 +43,7 @@ PassedCompilation()
 {
 	echo "$PassColour"
 	echo "-----------------------------------------------" | tee -a log.txt
-	echo " Passed Compilation - $testname                " | tee -a ../log.txt
+	echo " Compilation Success - $configuration_name" | tee -a log.txt
 	echo "-----------------------------------------------" | tee -a log.txt
 	echo "$NoColour"
 }
@@ -43,8 +52,8 @@ FailedCompilation()
 {
 	echo "$FailColour"
 	echo "****************************************************************************" | tee -a log.txt
-    echo "**** Failed Compilation $testname                                           " | tee -a log.txt
-	echo "****************************************************************************" | tee -a ../log.txt
+    echo "**** Failed Compilation $configuration_name" | tee -a log.txt
+	echo "****************************************************************************" | tee -a log.txt
 	echo "$NoColour"
 }
 
@@ -69,20 +78,29 @@ else
   export CMAKE_BUILD_PARALLEL_LEVEL=$1
 fi
 
-echo ""
-echo "Using "$CMAKE_BUILD_PARALLEL_LEVEL" concurrent processes"
+#******************************************************************************
+# Get the ETL version
+#******************************************************************************
+etl_version_raw=$(cat ../../version.txt)
+etl_version=$(echo $etl_version_raw | sed -e 's/\r//g') # Remove trailing \r
+
+#******************************************************************************
+# Get the compiler versions
+#******************************************************************************
+gcc_compiler=$(g++ --version | grep g++)
+clang_compiler=$(clang++ --version | grep clang)
 
 ###############################################################################
 cd c++03 || exit 1
 
 SetCxxStandard "03 (98)"
 
-SetTestName "GCC - STL"
+SetConfigurationName "STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -92,12 +110,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL"
+SetConfigurationName "No STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -107,12 +125,12 @@ else
   exit $?
 fi
 
-##SetTestName "GCC - No STL - User defined traits"
+##SetConfigurationName "No STL - User defined traits"
+#compiler=$gcc_compiler
 # PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#g++ --version | head --lines=1 | tee -a ../log.txt
 #CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bgcc
 #if [ $? -eq 0 ]; then
@@ -122,12 +140,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "GCC - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -137,12 +155,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -152,12 +170,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL"
+SetConfigurationName "STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -167,12 +185,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL"
+SetConfigurationName "No STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -182,12 +200,12 @@ else
   exit $?
 fi
 
-#SetTestName "Clang - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$clang_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#clang++ --version | head --lines=1 | tee -a ../log.txt
 #CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bclang
 #if [ $? -eq 0 ]; then
@@ -197,12 +215,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "Clang - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -212,12 +230,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -232,12 +250,12 @@ cd ../c++11 || exit 1
 
 SetCxxStandard "11"
 
-SetTestName "GCC - STL"
+SetConfigurationName "STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -247,12 +265,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -262,12 +280,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL"
+SetConfigurationName "No STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -277,12 +295,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -292,12 +310,12 @@ else
   exit $?
 fi
 
-#SetTestName "GCC - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$gcc_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#g++ --version | head --lines=1 | tee -a ../log.txt
 #CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bgcc
 #if [ $? -eq 0 ]; then
@@ -307,12 +325,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "GCC - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -322,12 +340,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -337,12 +355,12 @@ else
   exit $?
 fi
 
-SetTestName  "Clang - STL"
+SetConfigurationName  "STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -352,12 +370,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -367,12 +385,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL"
+SetConfigurationName "No STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -382,12 +400,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -397,13 +415,13 @@ else
   exit $?
 fi
 
-#SetTestName "Clang - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$clang_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#clang++ --version | head --lines=1 | tee -a ../log.txt
-#CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
+##CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bclang
 #if [ $? -eq 0 ]; then
 #  PassedCompilation
@@ -412,12 +430,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "Clang - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -427,12 +445,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -447,12 +465,12 @@ cd ../c++14 || exit 1
 
 SetCxxStandard "14"
 
-SetTestName "GCC - STL"
+SetConfigurationName "STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -462,12 +480,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -477,12 +495,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL"
+SetConfigurationName "No STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -492,12 +510,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -507,12 +525,12 @@ else
   exit $?
 fi
 
-#SetTestName "GCC - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$gcc_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#g++ --version | head --lines=1 | tee -a ../log.txt
 #CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bgcc
 #if [ $? -eq 0 ]; then
@@ -522,12 +540,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "GCC - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -537,12 +555,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -552,12 +570,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL"
+SetConfigurationName "STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -567,12 +585,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -582,12 +600,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL"
+SetConfigurationName "No STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -597,12 +615,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -612,13 +630,13 @@ else
   exit $?
 fi
 
-#SetTestName "Clang - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$clang_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#clang++ --version | head --lines=1 | tee -a ../log.txt
-#CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
+##CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bclang
 #if [ $? -eq 0 ]; then
 #  PassedCompilation
@@ -627,12 +645,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "Clang - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -642,12 +660,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -662,12 +680,12 @@ cd ../c++17 || exit 1
 
 SetCxxStandard "17"
 
-SetTestName "GCC - STL"
+SetConfigurationName "STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -677,12 +695,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -692,12 +710,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL"
+SetConfigurationName "No STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -707,12 +725,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -722,12 +740,12 @@ else
   exit $?
 fi
 
-#SetTestName "GCC - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$gcc_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#g++ --version | head --lines=1 | tee -a ../log.txt
 #CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bgcc
 #if [ $? -eq 0 ]; then
@@ -737,12 +755,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "GCC - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -752,12 +770,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -767,12 +785,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL"
+SetConfigurationName "STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -782,12 +800,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -797,12 +815,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL"
+SetConfigurationName "No STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -812,12 +830,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -827,12 +845,12 @@ else
   exit $?
 fi
 
-#SetTestName "Clang - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$clang_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#clang++ --version | head --lines=1 | tee -a ../log.txt
 #CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bclang
 #if [ $? -eq 0 ]; then
@@ -842,12 +860,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "Clang - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -857,12 +875,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -877,12 +895,12 @@ cd ../c++20 || exit 1
 
 SetCxxStandard "20"
 
-SetTestName "GCC - STL"
+SetConfigurationName "STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -892,12 +910,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -907,12 +925,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL"
+SetConfigurationName "No STL"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -922,12 +940,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -937,12 +955,12 @@ else
   exit $?
 fi
 
-#SetTestName "GCC - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$gcc_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#g++ --version | head --lines=1 | tee -a ../log.txt
 #CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bgcc
 #if [ $? -eq 0 ]; then
@@ -952,12 +970,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "GCC - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -967,12 +985,12 @@ else
   exit $?
 fi
 
-SetTestName "GCC - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$gcc_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=gcc CXX=g++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -982,12 +1000,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL"
+SetConfigurationName "STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -997,12 +1015,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - STL - Force C++03"
+SetConfigurationName "STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -1012,12 +1030,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL"
+SetConfigurationName "No STL"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -1027,12 +1045,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Force C++03"
+SetConfigurationName "No STL - Force C++03"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-clang++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=ON ..
 cmake --build bclang
 if [ $? -eq 0 ]; then
@@ -1042,12 +1060,12 @@ else
   exit $?
 fi
 
-#SetTestName "Clang - No STL - User defined traits"
+#SetConfigurationName "No STL - User defined traits"
+#compiler=$clang_compiler
 #PrintHeader
 #rm -rdf bgcc
 #rm -rdf bclang
 #cmake -E make_directory bgcc bclang
-#clang++ --version | head --lines=1 | tee -a ../log.txt
 #CC=clang CXX=clang++ cmake -E chdir bclang cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=OFF -DETL_USER_DEFINED_TYPE_TRAITS=ON -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 #cmake --build bclang
 #if [ $? -eq 0 ]; then
@@ -1057,12 +1075,12 @@ fi
 #  exit $?
 #fi
 
-SetTestName "Clang - STL - Built-in traits"
+SetConfigurationName "STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=OFF -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
@@ -1072,12 +1090,12 @@ else
   exit $?
 fi
 
-SetTestName "Clang - No STL - Built-in traits"
+SetConfigurationName "No STL - Built-in traits"
+compiler=$clang_compiler
 PrintHeader
 rm -rdf bgcc
 rm -rdf bclang
 cmake -E make_directory bgcc bclang
-g++ --version | head --lines=1 | tee -a ../log.txt
 CC=clang CXX=clang++ cmake -E chdir bgcc cmake -DNO_STL=ON -DETL_USE_TYPE_TRAITS_BUILTINS=ON -DETL_USER_DEFINED_TYPE_TRAITS=OFF -DETL_FORCE_TEST_CPP03_IMPLEMENTATION=OFF ..
 cmake --build bgcc
 if [ $? -eq 0 ]; then
