@@ -31,11 +31,14 @@ SOFTWARE.
 #include "etl/byte_stream.h"
 #include "etl/optional.h"
 #include "etl/span.h"
+#include "etl/array.h"
 
 #include <array>
 #include <numeric>
 #include <vector>
 
+#include "etl/private/diagnostic_useless_cast_push.h"
+
 namespace
 {
   //***********************************
@@ -1345,3 +1348,5 @@ namespace
     }
   };
 }
+
+#include "etl/private/diagnostic_pop.h"
