@@ -184,16 +184,16 @@ namespace
 
       etl::message_timer_locked<2> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Single_Shot);
 
       CHECK(id1 != etl::timer::id::NO_TIMER);
       CHECK(id2 != etl::timer::id::NO_TIMER);
       CHECK(id3 == etl::timer::id::NO_TIMER);
 
       timer_controller.clear();
-      id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::SINGLE_SHOT);
+      id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Single_Shot);
       CHECK(id3 != etl::timer::id::NO_TIMER);
 
       CHECK_EQUAL(0U, locks.lock_count);
@@ -209,9 +209,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Single_Shot);
 
       router1.clear();
 
@@ -252,7 +252,7 @@ namespace
 
       etl::message_timer_locked<1> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Single_Shot);
       router1.clear();
 
       timer_controller.start(id1);
@@ -305,9 +305,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -348,9 +348,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -395,9 +395,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -450,8 +450,8 @@ namespace
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
       etl::timer::id::type id1;
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -470,7 +470,7 @@ namespace
         {
           timer_controller.unregister_timer(id2);
 
-          id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::REPEATING);
+          id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
           timer_controller.start(id1);
         }
 
@@ -499,9 +499,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -548,9 +548,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, bus1, 37, etl::timer::mode::SINGLE_SHOT, ROUTER1);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, bus1, 23, etl::timer::mode::SINGLE_SHOT, ROUTER1);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, bus1, 11, etl::timer::mode::SINGLE_SHOT, etl::imessage_router::ALL_MESSAGE_ROUTERS);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, bus1, 37, etl::timer::mode::Single_Shot, ROUTER1);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, bus1, 23, etl::timer::mode::Single_Shot, ROUTER1);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, bus1, 11, etl::timer::mode::Single_Shot, etl::imessage_router::ALL_MESSAGE_ROUTERS);
 
       bus1.subscribe(router1);
 
@@ -593,9 +593,9 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::REPEATING);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -608,9 +608,9 @@ namespace
       ticks = 5;
       timer_controller.tick(uint32_t(ticks));
 
-      timer_controller.start(id1, etl::timer::start::IMMEDIATE);
-      timer_controller.start(id2, etl::timer::start::IMMEDIATE);
-      timer_controller.start(id3, etl::timer::start::DELAYED);
+      timer_controller.start(id1, etl::timer::start::Immediate);
+      timer_controller.start(id2, etl::timer::start::Immediate);
+      timer_controller.start(id3, etl::timer::start::Delayed);
 
       const uint32_t step = 1UL;
 
@@ -641,8 +641,8 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 15, etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1,  5, etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 15, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1,  5, etl::timer::mode::Repeating);
 
       router1.clear();
 
@@ -680,7 +680,7 @@ namespace
 
       etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 5, etl::timer::mode::SINGLE_SHOT);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 5, etl::timer::mode::Single_Shot);
 
       router1.clear();
 
@@ -715,6 +715,100 @@ namespace
       CHECK_EQUAL(0U, locks.lock_count);
     }
 
+    //*************************************************************************
+    TEST(message_timer_time_to_next)
+    {
+      locks.clear();
+      try_lock_type try_lock = try_lock_type::create<Locks, locks, &Locks::try_lock>();
+      lock_type     lock     = lock_type::create<Locks, locks, &Locks::lock>();
+      unlock_type   unlock   = unlock_type::create<Locks, locks, &Locks::unlock>();
+
+      etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
+
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Repeating);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Repeating);
+
+      router1.clear();
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      CHECK_EQUAL(11, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(4, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(8, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(1, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(5, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(2, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(2, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(6, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(10, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(3, timer_controller.time_to_next());
+
+      timer_controller.tick(7);
+      CHECK_EQUAL(4, timer_controller.time_to_next());
+    }
+
+    //*************************************************************************
+    TEST(message_timer_time_to_next_with_has_active_timer)
+    {
+      locks.clear();
+      try_lock_type try_lock = try_lock_type::create<Locks, locks, &Locks::try_lock>();
+      lock_type     lock     = lock_type::create<Locks, locks, &Locks::lock>();
+      unlock_type   unlock   = unlock_type::create<Locks, locks, &Locks::unlock>();
+
+      etl::message_timer_locked<3> timer_controller(try_lock, lock, unlock);
+
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 37, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 23, etl::timer::mode::Single_Shot);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 11, etl::timer::mode::Single_Shot);
+
+      router1.clear();
+
+      timer_controller.start(id1);
+      timer_controller.start(id3);
+      timer_controller.start(id2);
+
+      timer_controller.enable(true);
+
+      timer_controller.tick(11);
+      CHECK_EQUAL(12, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(23);
+      CHECK_EQUAL(3, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(2);
+      CHECK_EQUAL(1, timer_controller.time_to_next());
+      CHECK_TRUE(timer_controller.has_active_timer());
+
+      timer_controller.tick(1);
+      CHECK_EQUAL(static_cast<etl::timer::interval::type>(etl::timer::interval::No_Active_Interval), timer_controller.time_to_next());
+      CHECK_FALSE(timer_controller.has_active_timer());
+    }
+
     //*************************************************************************
 #if REALTIME_TEST
 
@@ -763,9 +857,9 @@ namespace
     {
       FIX_PROCESSOR_AFFINITY;
 
-      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 400,  etl::timer::mode::SINGLE_SHOT);
-      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 100,  etl::timer::mode::REPEATING);
-      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 10,   etl::timer::mode::REPEATING);
+      etl::timer::id::type id1 = timer_controller.register_timer(message1, router1, 400,  etl::timer::mode::Single_Shot);
+      etl::timer::id::type id2 = timer_controller.register_timer(message2, router1, 100,  etl::timer::mode::Repeating);
+      etl::timer::id::type id3 = timer_controller.register_timer(message3, router1, 10,   etl::timer::mode::Repeating);
 
       router1.clear();
 
