@@ -35,6 +35,9 @@ SOFTWARE.
 #include <vector>
 #include <algorithm>
 #include <iterator>
+#if ETL_USING_CPP20
+  #include <span>
+#endif
 
 namespace
 {
@@ -42,12 +45,16 @@ namespace
   {
     static const size_t SIZE = 10UL;
 
-    typedef etl::array<int, SIZE> EtlData;
-    typedef std::array<int, SIZE> StlData;
-    typedef std::vector<int> StlVData;
+    using EtlData  = etl::array<int, SIZE>;
+    using StlData  = std::array<int, SIZE>;
+    using StlVData = std::vector<int>;
 
-    typedef etl::span<int> View;
-    typedef etl::span<const int> CView;
+    using View  = etl::span<int>;
+    using CView = etl::span<const int>;
+
+#if ETL_USING_CPP20
+    using StdView = std::span<int>;
+#endif
 
     EtlData etldata = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     StlData stldata = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
@@ -78,6 +85,21 @@ namespace
       CHECK(view.empty());
     }
 
+#if ETL_USING_CPP20
+    //*************************************************************************
+    TEST(test_construct_from_std_span)
+    {
+      StdView stdview(stldata);
+      View view(stdview);
+
+      CHECK_EQUAL(stdview.size(), view.size());
+      CHECK_EQUAL(stdview.size(), view.size());
+
+      bool isEqual = std::equal(view.begin(), view.end(), stdview.begin());
+      CHECK(isEqual);
+    }
+#endif
+
     //*************************************************************************
     TEST(test_constructor_etl_array_1)
     {
@@ -1010,7 +1032,7 @@ namespace
       etl::array<int, 10> data3{ 0, 1, 2, 3, 4, 4, 6, 7, 8, 9 };
       etl::array<int, 9>  data4{ 0, 1, 2, 3, 5, 6, 7, 8, 9 };
 
-      int i;
+      int i = 1;
 
       View view1{ data1 };
       View view2{ data1 };
@@ -1048,7 +1070,7 @@ namespace
       etl::array<int, 10> data3{ 0, 1, 2, 3, 4, 4, 6, 7, 8, 9 };
       etl::array<int, 9>  data4{ 0, 1, 2, 3, 5, 6, 7, 8, 9 };
 
-      int i;
+      int i = 1;
 
       View view1{ data1 };
       CView view2{ data1 };
@@ -1086,7 +1108,7 @@ namespace
       etl::array<int, 10> data3{ 0, 1, 2, 3, 4, 4, 6, 7, 8, 9 };
       etl::array<int, 10> data4{ 0, 1, 2, 3, 5, 6, 7, 8, 9 };
 
-      int i;
+      int i = 1;
 
       View view1{ data1 };
       View view2{ data1 };
@@ -1124,7 +1146,7 @@ namespace
       etl::array<int, 10> data3{ 0, 1, 2, 3, 4, 4, 6, 7, 8, 9 };
       etl::array<int, 9>  data4{ 0, 1, 2, 3, 5, 6, 7, 8, 9 };
 
-      int i;
+      int i = 1;
 
       View view1{ data1 };
       CView view2{ data1 };
@@ -1165,6 +1187,22 @@ namespace
 
       CHECK_EQUAL(const_bytes.size(),    sizeof(data));
       CHECK_EQUAL(writable_bytes.size(), sizeof(data));
+
+      etl::byte* pdata = reinterpret_cast<etl::byte*>(data);
+
+      // Test the reading of bytes.
+      for (size_t i = 0; i < sizeof(data); ++i)
+      {
+        CHECK_EQUAL(int(pdata[i]), int(const_bytes[i]));
+        CHECK_EQUAL(int(pdata[i]), int(writable_bytes[i]));
+      }
+
+      // Test writing of bytes.
+      for (size_t i = 0; i < writable_bytes.size(); ++i)
+      {
+        writable_bytes[i] = ~writable_bytes[i];
+        CHECK_EQUAL(int(pdata[i]), int(writable_bytes[i]));
+      }
     }
 
 #include "etl/private/diagnostic_pop.h"
