@@ -35,6 +35,9 @@ SOFTWARE.
 #include <vector>
 #include <algorithm>
 #include <iterator>
+#if ETL_USING_CPP20
+  #include <span>
+#endif
 
 namespace
 {
@@ -47,8 +50,13 @@ namespace
     typedef std::vector<int> StlVData;
 
     typedef etl::span<int, 10U> View;
+    typedef etl::span<int, 9U> SView;
     typedef etl::span<const int, 10U> CView;
 
+#if ETL_USING_CPP20
+    using StdView = std::span<int, 10U>;
+#endif
+
     EtlData etldata = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     StlData stldata = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     StlVData stlvdata = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
@@ -68,15 +76,20 @@ namespace
     const int ccdata[] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
     const int* pccdata = ccdata;
 
+#if ETL_USING_CPP20
     //*************************************************************************
-    TEST(test_default_constructor)
+    TEST(test_construct_from_std_span)
     {
-      View view;
+      StdView stdview(stldata);
+      View view(stdview);
 
-      CHECK_EQUAL(10U, view.size());
-      CHECK_EQUAL(10U, view.max_size());
-      CHECK(!view.empty());
+      CHECK_EQUAL(stdview.size(), view.size());
+      CHECK_EQUAL(stdview.size(), view.size());
+
+      bool isEqual = std::equal(view.begin(), view.end(), stdview.begin());
+      CHECK(isEqual);
     }
+#endif
 
     //*************************************************************************
     TEST(test_constructor_etl_array_1)
@@ -249,9 +262,7 @@ namespace
     //*************************************************************************
     TEST(test_implicit_constructor_c_array_2)
     {
-      CView view;
-
-      view = ccdata;
+      CView view(ccdata);
 
       CHECK_EQUAL(SIZE, view.size());
       CHECK_EQUAL(SIZE, view.max_size());
@@ -339,12 +350,11 @@ namespace
     TEST(test_assign_from_span)
     {
       View view1(etldata);
-      View view2;
+      View view2 = view1;
 
       CView cview1(etldata);
-      CView cview2;
+      CView cview2 = view2;
 
-      view2 = view1;
       cview2 = cview1;
 
       CHECK_EQUAL(view1.size(), view2.size());
@@ -998,25 +1008,23 @@ namespace
       etl::array<int, 10> data1{ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
       etl::array<int, 10> data2{ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9 };
       etl::array<int, 10> data3{ 0, 1, 2, 3, 4, 4, 6, 7, 8, 9 };
+      etl::array<int, 9>  data4{ 0, 1, 2, 3, 4, 5, 6, 7, 8 };
 
       View view1{ data1 };
       View view2{ data1 };
       View view3{ data2 };
       View view4{ data3 };
-      View view6;
-      View view7;
+      SView view8{ data4 };
 
       CHECK_TRUE(etl::equal(view1, view2));
       CHECK_TRUE(etl::equal(view1, view3));
       CHECK_FALSE(etl::equal(view1, view4));
-      CHECK_TRUE(etl::equal(view6, view6));
-      CHECK_TRUE(etl::equal(view6, view7));
+      CHECK_FALSE(etl::equal(view1, view8));
 
       CHECK_TRUE(view1 == view2);
       CHECK_FALSE(view1 == view3);
       CHECK_FALSE(view1 == view4);
-      CHECK_TRUE(view6 == view6);
-      CHECK_TRUE(view6 == view7);
+      CHECK_FALSE(view1 == view8);
     }
 
     //*************************************************************************
@@ -1030,20 +1038,14 @@ namespace
       CView view2{ data1 };
       CView view3{ data2 };
       CView view4{ data3 };
-      View view6;
-      CView view7;
 
       CHECK_TRUE(etl::equal(view1, view2));
       CHECK_TRUE(etl::equal(view1, view3));
       CHECK_FALSE(etl::equal(view1, view4));
-      CHECK_TRUE(etl::equal(view6, view6));
-      CHECK_TRUE(etl::equal(view6, view7));
 
       CHECK_TRUE(view1 == view2);
       CHECK_FALSE(view1 == view3);
       CHECK_FALSE(view1 == view4);
-      CHECK_TRUE(view6 == view6);
-      CHECK_TRUE(view6 == view7);
     }
 
     //*************************************************************************
@@ -1057,20 +1059,14 @@ namespace
       View view2{ data1 };
       View view3{ data2 };
       View view4{ data3 };
-      View view6;
-      View view7;
 
       CHECK_TRUE(etl::equal(view1, view2));
       CHECK_TRUE(etl::equal(view1, view3));
       CHECK_FALSE(etl::equal(view1, view4));
-      CHECK_TRUE(etl::equal(view6, view6));
-      CHECK_TRUE(etl::equal(view6, view7));
 
       CHECK_FALSE(view1 != view2);
       CHECK_TRUE(view1 != view3);
       CHECK_TRUE(view1 != view4);
-      CHECK_FALSE(view6 != view6);
-      CHECK_FALSE(view6 != view7);
     }
 
     //*************************************************************************
@@ -1084,20 +1080,14 @@ namespace
       CView view2{ data1 };
       CView view3{ data2 };
       CView view4{ data3 };
-      View view6;
-      View view7;
 
       CHECK_TRUE(etl::equal(view1, view2));
       CHECK_TRUE(etl::equal(view1, view3));
       CHECK_FALSE(etl::equal(view1, view4));
-      CHECK_TRUE(etl::equal(view6, view6));
-      CHECK_TRUE(etl::equal(view6, view7));
 
       CHECK_FALSE(view1 != view2);
       CHECK_TRUE(view1 != view3);
       CHECK_TRUE(view1 != view4);
-      CHECK_FALSE(view6 != view6);
-      CHECK_FALSE(view6 != view7);
     }
 
     //*************************************************************************
@@ -1115,6 +1105,22 @@ namespace
 
       CHECK_EQUAL(const_bytes.size(),    sizeof(data));
       CHECK_EQUAL(writable_bytes.size(), sizeof(data));
+
+      etl::byte* pdata = reinterpret_cast<etl::byte*>(data);
+
+      // Test the reading of bytes.
+      for (size_t i = 0; i < sizeof(data); ++i)
+      {
+        CHECK_EQUAL(int(pdata[i]), int(const_bytes[i]));
+        CHECK_EQUAL(int(pdata[i]), int(writable_bytes[i]));
+      }
+
+      // Test writing of bytes.
+      for (size_t i = 0; i < writable_bytes.size(); ++i)
+      {
+        writable_bytes[i] = ~writable_bytes[i];
+        CHECK_EQUAL(int(pdata[i]), int(writable_bytes[i]));
+      }
     }
 
 #include "etl/private/diagnostic_pop.h"
