@@ -462,6 +462,7 @@ namespace
       data1.insert(DataM::value_type(std::string("3"), etl::move(d3)));
       data1.insert(DataM::value_type(std::string("4"), ItemM(4)));
 
+      data2.insert(DataM::value_type(std::string("5"), ItemM(5)));
       data2 = std::move(data1);
 
       CHECK_EQUAL(1, data2.at("1").value);
@@ -1192,5 +1193,19 @@ namespace
       using Map = etl::unordered_map<int, int, 1, 1>;
       CHECK((!std::is_same<typename Map::const_iterator::value_type, typename Map::iterator::value_type>::value));
     }
+
+    //*************************************************************************
+    TEST(test_iterator_value_types_bug_803)
+    {
+      using Map1 = etl::unordered_map<std::string, NDC, SIZE, 5>;
+      using Map2 = etl::unordered_map<std::string, NDC, 2 * SIZE, 10>;
+      
+      Map1 map1(initial_data.begin(), initial_data.end());
+      Map2 map2a(initial_data.begin(), initial_data.end());
+      Map2 map2b(different_data.begin(), different_data.end());
+      
+      CHECK_TRUE(map1 == map2a);
+      CHECK_FALSE(map1 == map2b);
+    }
   };
 }
