@@ -414,6 +414,7 @@ namespace
       data1.insert(DataM::value_type(std::string("4"), ItemM(4)));
 
       data2 = std::move(data1);
+      data2.insert(DataM::value_type(std::string("5"), ItemM(5)));
 
       CHECK_EQUAL(1, data2.find("1")->second.value);
       CHECK_EQUAL(2, data2.find("2")->second.value);
@@ -1029,6 +1030,7 @@ namespace
       CHECK((!std::is_same<typename Map::const_iterator::value_type, typename Map::iterator::value_type>::value));
     }
 
+    //*************************************************************************
     TEST(test_parameterized_eq)
     {
       constexpr std::size_t MODULO = 4;
@@ -1052,5 +1054,19 @@ namespace
         CHECK_EQUAL(std::distance(range.first, range.second), 3);
       }
     }
+
+    //*************************************************************************
+    TEST(test_iterator_value_types_bug_803)
+    {
+      using Map1 = etl::unordered_multimap<std::string, NDC, SIZE, 5>;
+      using Map2 = etl::unordered_multimap<std::string, NDC, 2 * SIZE, 10>;
+
+      Map1 map1(initial_data.begin(), initial_data.end());
+      Map2 map2a(initial_data.begin(), initial_data.end());
+      Map2 map2b(different_data.begin(), different_data.end());
+
+      CHECK_TRUE(map1 == map2a);
+      CHECK_FALSE(map1 == map2b);
+    }
   };
 }
