@@ -34,6 +34,7 @@
 #include <memory>
 
 #include "etl/vector.h"
+#include "etl/math.h"
 #include "data.h"
 
 namespace
@@ -212,7 +213,6 @@ namespace
     //*************************************************************************
     TEST(test_move_constructor)
     {
-      const size_t SIZE = 10U;
       typedef etl::vector<std::unique_ptr<uint32_t>, SIZE> Data;
 
       std::unique_ptr<uint32_t> p1(new uint32_t(1U));
@@ -255,7 +255,6 @@ namespace
     //*************************************************************************
     TEST(test_move_assignment)
     {
-      const size_t SIZE = 10U;
       typedef etl::vector<std::unique_ptr<uint32_t>, SIZE> Data;
 
       std::unique_ptr<uint32_t> p1(new uint32_t(1U));
@@ -302,7 +301,6 @@ namespace
     //*************************************************************************
     TEST(test_move_assignment_interface)
     {
-      const size_t SIZE = 10U;
       typedef etl::vector<std::unique_ptr<uint32_t>, SIZE> Data;
       typedef etl::ivector<std::unique_ptr<uint32_t>> IData;
 
@@ -771,7 +769,6 @@ namespace
 #endif
 
     //*************************************************************************
-    // To test the CPP03 versions then ETL_TEST_VECTOR_CPP11 must be set to 0 in vector.h
     TEST_FIXTURE(SetupFixture, test_emplace_back_multiple)
     {
       class Data
@@ -787,10 +784,12 @@ namespace
         Data(std::string w, size_t x, double y, const char *z) : a(w), b(x), c(y), d(z){}
         bool operator == (const Data &other) const
         {
+#include "etl/private/diagnostic_float_equal_push.h"
           return (a == other.a) &&
                  (b == other.b) &&
                  (c == other.c) &&
                  (((d == nullptr) && (other.d == nullptr)) || (strcmp(d, other.d) == 0));
+#include "etl/private/diagnostic_pop.h"
         }
       };
 
@@ -847,7 +846,7 @@ namespace
         Data(std::string &w, size_t &x, double &y, const char *z) : a(w), b(x), c(y), d(z){}
         bool operator == (const Data &other) const
         {
-          return (a == other.a) && (b == other.b) && (c == other.c) && (d == other.d);
+          return (a == other.a) && (b == other.b) && !(c < other.c) && !(c > other.c) && (d == other.d);
         }
       };
 
